@@ -1,6 +1,6 @@
 /*
  *   This file is part of AkariXB
- *   Copyright 2015-2016  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2015-2018  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -76,7 +76,7 @@ ActivityModule::ActivityModule(ActivityHandler *handler,
     timesPerDaySpinbox->setRange(1, 100);
 
     this->probabilitySpinbox = new QSpinBox(this);
-    probabilitySpinbox->setRange(1, 100);
+    probabilitySpinbox->setRange(0, 100);
     probabilitySpinbox->setValue(50);
     probabilitySpinbox->setSuffix("%");
 
@@ -128,27 +128,30 @@ ActivityModule::ActivityModule(ActivityHandler *handler,
     this->msgAfterListWidget = new StringListWidget(false, this);
 
 
-    // Send messsages to: all rooms/some rooms/few rooms/specific jids + active private conversations
+    // Send messsages to:
+    //   All rooms/some rooms/few rooms + active private conversations + specific jids
     this->msgToRoomsCombobox = new QComboBox(this);
-    msgToRoomsCombobox->addItem(tr("All rooms")     + " [Not implemented]"); // tmp/FIXME
-    msgToRoomsCombobox->addItem(tr("Several rooms") + " [Not implemented]"); // tmp/FIXME
-    msgToRoomsCombobox->addItem(tr("A few rooms")   + " [Not implemented]"); // tmp/FIXME
-    msgToRoomsCombobox->addItem(tr("Specific JIDs") + " [Only First JID]");  // tmp/FIXME
-    connect(msgToRoomsCombobox, SIGNAL(currentIndexChanged(int)),
-            this, SLOT(onRecipientsTypeChanged(int)));
+    msgToRoomsCombobox->addItem(tr("All rooms"));
+    msgToRoomsCombobox->addItem(tr("Several rooms"));
+    msgToRoomsCombobox->addItem(tr("A few rooms"));
+    msgToRoomsCombobox->addItem(tr("None of the rooms"));
 
 
+    this->msgToActiveChatsCheckbox = new QCheckBox(tr("Also to active "
+                                                      "private chats"),
+                                                   this);
+    msgToActiveChatsCheckbox->setDisabled(true); // TMP FIXME: Until the setting is implemented
+
+
+    this->specificJidsText = new QLabel(tr("Additional specific JIDs:"), this);
+
     // FIXME? Probably better to use a StringListWidget, and put it below
     this->specificJidsLineEdit = new QLineEdit(this);
-    specificJidsLineEdit->setToolTip(tr("List of room or user addresses, "
-                                        "separated by space"));
-    specificJidsLineEdit->hide();
+    specificJidsLineEdit->setToolTip("<b></b>"
+                                     + tr("List of room or user addresses, "
+                                          "separated by space"));
 
 
-    this->msgToChatsCheckbox = new QCheckBox(tr("Also to active private chats"),
-                                             this);
-    msgToChatsCheckbox->setDisabled(true); // TMP FIXME: Until the setting is implemented
-
 
     this->saveActivityButton = new QPushButton(QIcon::fromTheme("document-save",
                                                                 QIcon(":/images/button-save.png")),
@@ -186,10 +189,18 @@ ActivityModule::ActivityModule(ActivityHandler *handler,
     reactionLayout->addSpacing(8);
     reactionLayout->addWidget(maxReactionSpinbox);
 
-    this->msgRecipientsLayout = new QHBoxLayout();
-    msgRecipientsLayout->addWidget(msgToRoomsCombobox);
-    msgRecipientsLayout->addWidget(specificJidsLineEdit);
-    msgRecipientsLayout->addWidget(msgToChatsCheckbox);
+
+    this->recipientsTopLayout = new QHBoxLayout();
+    recipientsTopLayout->addWidget(msgToRoomsCombobox);
+    recipientsTopLayout->addWidget(msgToActiveChatsCheckbox);
+
+    this->recipientsBottomLayout = new QHBoxLayout();
+    recipientsBottomLayout->addWidget(specificJidsText);
+    recipientsBottomLayout->addWidget(specificJidsLineEdit);
+
+    this->msgRecipientsLayout = new QVBoxLayout();
+    msgRecipientsLayout->addLayout(recipientsTopLayout);
+    msgRecipientsLayout->addLayout(recipientsBottomLayout);
 
 
     this->formLayout = new QFormLayout();
@@ -275,8 +286,8 @@ void ActivityModule::loadActivities()
         item->setData(Qt::UserRole + 15, map.value("msgBefore"));
         item->setData(Qt::UserRole + 16, map.value("msgAfter"));
         item->setData(Qt::UserRole + 17, map.value("msgToRooms"));
-        item->setData(Qt::UserRole + 18, map.value("specificJids"));
-        item->setData(Qt::UserRole + 19, map.value("msgToChats"));
+        item->setData(Qt::UserRole + 18, map.value("msgToChats"));
+        item->setData(Qt::UserRole + 19, map.value("specificJids"));
 
 
         this->activityListWidget->addItem(item);
@@ -309,11 +320,6 @@ void ActivityModule::onNameChanged(QString newName)
 }
 
 
-void ActivityModule::onRecipientsTypeChanged(int option)
-{
-    this->specificJidsLineEdit->setVisible(option == 3); // Visible only for Specific JIDs option
-}
-
 
 void ActivityModule::addActivity()
 {
@@ -353,15 +359,14 @@ void ActivityModule::addActivity()
 
     // Nothing to set here for the lists (UR + 14, 15, 16)
 
-    // Send messages to...
+    // Send messages to all/several/few room
     item->setData(Qt::UserRole + 17, 0);
 
-    // Specific recipient JIDs
-    item->setData(Qt::UserRole + 18, "");
-
     // Messages also to active private chats
-    item->setData(Qt::UserRole + 19, true);
+    item->setData(Qt::UserRole + 18, true);
 
+    // Specific recipient JIDs
+    item->setData(Qt::UserRole + 19, "");
 
     this->activityListWidget->addItem(item);
 
@@ -432,8 +437,8 @@ void ActivityModule::onActivitySelected(int row)
     this->msgAfterListWidget->addStringsToList(item->data(Qt::UserRole + 16).toStringList());
 
     this->msgToRoomsCombobox->setCurrentIndex(item->data(Qt::UserRole + 17).toInt());
-    this->specificJidsLineEdit->setText(item->data(Qt::UserRole + 18).toString());
-    this->msgToChatsCheckbox->setChecked(item->data(Qt::UserRole + 19).toBool());
+    this->msgToActiveChatsCheckbox->setChecked(item->data(Qt::UserRole + 18).toBool());
+    this->specificJidsLineEdit->setText(item->data(Qt::UserRole + 19).toString());
 
 
     this->removeActivityButton->setEnabled(true);
@@ -499,8 +504,8 @@ void ActivityModule::saveActivity()
     item->setData(Qt::UserRole + 16, msgAfterListWidget->getStringsFromList());
 
     item->setData(Qt::UserRole + 17, msgToRoomsCombobox->currentIndex());
-    item->setData(Qt::UserRole + 18, specificJidsLineEdit->text());
-    item->setData(Qt::UserRole + 19, msgToChatsCheckbox->isChecked());
+    item->setData(Qt::UserRole + 18, msgToActiveChatsCheckbox->isChecked());
+    item->setData(Qt::UserRole + 19, specificJidsLineEdit->text());
 
 
 
@@ -516,8 +521,11 @@ void ActivityModule::syncActivities()
     {
         QListWidgetItem *item = activityListWidget->item(counter);
 
+        const QString activityName = item->data(Qt::UserRole).toString()
+                                                             .trimmed();
+
         QVariantMap activityMap;
-        activityMap.insert("name",           item->data(Qt::UserRole));
+        activityMap.insert("name",           activityName);
         activityMap.insert("timesPerDay",    item->data(Qt::UserRole + 1));
         activityMap.insert("probability",    item->data(Qt::UserRole + 2));
         activityMap.insert("minTime",        item->data(Qt::UserRole + 3));
@@ -535,11 +543,15 @@ void ActivityModule::syncActivities()
         activityMap.insert("msgBefore",      item->data(Qt::UserRole + 15));
         activityMap.insert("msgAfter",       item->data(Qt::UserRole + 16));
         activityMap.insert("msgToRooms",     item->data(Qt::UserRole + 17));
-        activityMap.insert("specificJids",   item->data(Qt::UserRole + 18));
-        activityMap.insert("msgToChats",     item->data(Qt::UserRole + 19));
+        activityMap.insert("msgToChats",     item->data(Qt::UserRole + 18));
+        activityMap.insert("specificJids",   item->data(Qt::UserRole + 19));
 
 
-        activityDataList.append(activityMap);
+        // Don't save activities without a name
+        if (!activityName.isEmpty())
+        {
+            activityDataList.append(activityMap);
+        }
     }
 
     this->activityHandler->setActivityData(activityDataList);
