@@ -1,6 +1,6 @@
 /*
  *   This file is part of AkariXB
- *   Copyright 2015-2016  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2015-2018  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -27,6 +27,7 @@
 #include <QFormLayout>
 #include <QScrollArea>
 #include <QListWidget>
+#include <QLabel>
 #include <QLineEdit>
 #include <QComboBox>
 #include <QSpinBox>
@@ -66,8 +67,6 @@ signals:
 public slots:
     void onNameChanged(QString newName);
 
-    void onRecipientsTypeChanged(int option);
-
     void addActivity();
     void removeActivity();
 
@@ -124,10 +123,13 @@ private:
     StringListWidget *msgBeforeListWidget;
     StringListWidget *msgAfterListWidget;
 
-    QHBoxLayout *msgRecipientsLayout;
+    QVBoxLayout *msgRecipientsLayout;
+    QHBoxLayout *recipientsTopLayout;
     QComboBox *msgToRoomsCombobox;
-    QLineEdit *specificJidsLineEdit;
-    QCheckBox *msgToChatsCheckbox;
+    QCheckBox *msgToActiveChatsCheckbox;
+    QHBoxLayout *recipientsBottomLayout;
+    QLabel *specificJidsText;
+    QLineEdit *specificJidsLineEdit;    
 
     QPushButton *saveActivityButton;
 
