@@ -1,6 +1,6 @@
 /*
  *   This file is part of AkariXB
- *   Copyright 2015-2016  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2015-2018  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -24,6 +24,8 @@ ChatModule::ChatModule(GlobalObject *globalObject,
                        QWidget *parent) : QWidget(parent)
 {
     this->globalObj = globalObject;
+    connect(globalObj, SIGNAL(privateMessageSent(QString,QString)),
+            this, SLOT(addOutgoingMessage(QString,QString)));
 
     this->xmppClient = this->globalObj->getXmppClient();
 
@@ -38,6 +40,12 @@ ChatModule::ChatModule(GlobalObject *globalObject,
     connect(tabWidget, SIGNAL(tabCloseRequested(int)),
             this, SLOT(closeTab(int)));
 
+    this->closeTabAction = new QAction(this);
+    closeTabAction->setShortcut(QKeySequence("Ctrl+W"));
+    connect(closeTabAction, SIGNAL(triggered(bool)),
+            this, SLOT(closeCurrentTab()));
+    this->addAction(closeTabAction);
+
 
     this->mainLayout = new QVBoxLayout();
     mainLayout->setContentsMargins(0, 0, 0, 0);
@@ -64,21 +72,17 @@ void ChatModule::setTabTitle(int tabNumber, QString name, int unread)
     this->tabWidget->setTabText(tabNumber, name);
 }
 
-
-
-//////////////////////////////////////////////////////////////////////////////
-///////////////////////////////////// SLOTS //////////////////////////////////
-//////////////////////////////////////////////////////////////////////////////
-
-
-
-void ChatModule::addChatTab(QXmppMessage message)
+/*
+ * Find or create a new tab with a ChatWidget for a given Jid
+ *
+ */
+int ChatModule::tabForJid(QString jid)
 {
-    QString bareFrom = message.from().split("/").first();
+    QString bareJid = jid.split("/").first();
 
     // If this is a private message via MUC room
     bool fromMuc = false;
-    if (this->globalObj->getJoinedRooms().contains(bareFrom))
+    if (this->globalObj->getJoinedRooms().contains(bareJid))
     {
         // Will use full JID as title, and resource as nickname
         fromMuc = true;
@@ -90,7 +94,7 @@ void ChatModule::addChatTab(QXmppMessage message)
     {
         if (fromMuc)
         {
-            if (openedChats.at(tabCount)->getContactJid() == message.from())
+            if (openedChats.at(tabCount)->getContactJid() == jid)
             {
                 tabFound = true;
                 break;
@@ -98,7 +102,7 @@ void ChatModule::addChatTab(QXmppMessage message)
         }
         else
         {
-            if (openedChats.at(tabCount)->getContactBareJid() == bareFrom)
+            if (openedChats.at(tabCount)->getContactBareJid() == bareJid)
             {
                 tabFound = true;
                 break;
@@ -107,64 +111,82 @@ void ChatModule::addChatTab(QXmppMessage message)
     }
 
 
-    ChatWidget *currentChatWidget;
+    ChatWidget *chatWidget;
     if (tabFound)
     {
-        currentChatWidget = openedChats.at(tabCount);
-        currentChatWidget->appendMessage(message);
+        chatWidget = openedChats.at(tabCount);
     }
     else
     {
-        currentChatWidget = new ChatWidget(this->globalObj, this);
-        openedChats.append(currentChatWidget);
+        chatWidget = new ChatWidget(this->globalObj, this);
+        openedChats.append(chatWidget);
 
-        tabWidget->addTab(currentChatWidget,
+        tabWidget->addTab(chatWidget,
                           QIcon::fromTheme("user-identity",
                                            QIcon(":/images/no-avatar.png")),
-                          bareFrom);
+                          bareJid);
 
-        currentChatWidget->setContact(message.from());
+        chatWidget->setContact(jid);
 
         QString tabTitle;
         if (fromMuc)
         {
-            tabTitle = message.from(); // Full JID, room@server/nickname
-            QStringList contactNick = message.from().split("/");
+            tabTitle = jid; // Full JID, room@server/nickname
+            QStringList contactNick = jid.split("/");
             contactNick.removeFirst(); // Can't just use .last(), since nickname could contain "/"
-            currentChatWidget->setContactNick(contactNick.join("/"));
+            chatWidget->setContactNick(contactNick.join("/"));
         }
         else
         {
-            tabTitle = message.from().split("/").first(); // Username part of JID
+            tabTitle = bareJid; // Username part of JID
         }
 
-        currentChatWidget->setChatTitle(tabTitle);
-        currentChatWidget->appendMessage(message);
+        chatWidget->setChatTitle(tabTitle);
 
         // It's important to connect() *after* the tab has been added
-        connect(currentChatWidget, SIGNAL(messagesRead(int)),
+        connect(chatWidget, SIGNAL(messagesRead(int)),
                 this, SLOT(updateTabTitle(int)));
 
+
+
         globalObj->addToLog(tr("Chat started by %1.",
-                               "%1 = A nickname").arg(message.from()));
+                               "%1 = A nickname").arg(jid));
 
         if (globalObj->getNotifyNewChats())
         {
             globalObj->showNotification(tr("New chat"),
                                         tr("A new chat was started by %1.")
-                                        .arg(message.from()));
+                                        .arg(jid));
         }
 
-        // TODO: optional email notification for this event
+        // TODO: optional email/XMPP notification for this event
     }
 
 
+    return tabCount;
+}
+
+
+
+//////////////////////////////////////////////////////////////////////////////
+///////////////////////////////////// SLOTS //////////////////////////////////
+//////////////////////////////////////////////////////////////////////////////
+
+
+
+void ChatModule::addChatTab(QXmppMessage message)
+{
+    int tabNumber = this->tabForJid(message.from());
+
+    ChatWidget *currentChatWidget = this->openedChats.at(tabNumber);
+    currentChatWidget->appendMessage(message);
+
+
     // Update title of that tab, not necessarily current tab
-    this->setTabTitle(tabCount,
+    this->setTabTitle(tabNumber,
                       currentChatWidget->getChatTitle(),
                       currentChatWidget->getUnreadCount());
 
-
     if (!currentChatWidget->isVisible())
     {
         ++unreadCount;
@@ -195,3 +217,29 @@ void ChatModule::closeTab(int tabIndex)
     this->openedChats.removeAt(tabIndex);
 }
 
+void ChatModule::closeCurrentTab()
+{
+    int currentTab = this->tabWidget->currentIndex();
+    if (currentTab != -1)
+    {
+        this->closeTab(currentTab);
+    }
+}
+
+
+void ChatModule::addOutgoingMessage(QString toJid, QString message)
+{
+    qDebug() << "Sending private message to" << toJid << ": " << message;
+
+    int tabNumber = this->tabForJid(toJid);
+
+    ChatWidget *currentChatWidget = this->openedChats.at(tabNumber);
+    currentChatWidget->appendOutgoingMessage(message);
+
+
+    // Update title of that tab, not necessarily current tab
+    this->setTabTitle(tabNumber,
+                      currentChatWidget->getChatTitle(),
+                      currentChatWidget->getUnreadCount());
+}
+
