@@ -1,6 +1,6 @@
 /*
  *   This file is part of AkariXB
- *   Copyright 2015-2016  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2015-2018  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -26,6 +26,7 @@
 #include <QLabel>
 #include <QTabWidget>
 #include <QTabBar>
+#include <QAction>
 
 #include <QDebug>
 
@@ -44,6 +45,7 @@ public:
     ~ChatModule();
 
     void setTabTitle(int tabNumber, QString name, int unread);
+    int tabForJid(QString jid);
 
 
 signals:
@@ -54,6 +56,8 @@ public slots:
     void addChatTab(QXmppMessage message);
     void updateTabTitle(int count);
     void closeTab(int tabIndex);
+    void closeCurrentTab();
+    void addOutgoingMessage(QString toJid, QString message);
 
 
 private:
@@ -62,6 +66,8 @@ private:
 
     QList<ChatWidget *> openedChats;
 
+    QAction *closeTabAction;
+
     int unreadCount;
 
     QXmppClient *xmppClient;
