@@ -1,6 +1,6 @@
 /*
  *   This file is part of AkariXB
- *   Copyright 2015-2016  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2015-2018  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -247,6 +247,45 @@ void ChatWidget::appendMessage(QXmppMessage message)
 
 
 
+
+void ChatWidget::appendOutgoingMessage(QString messageText)
+{
+    QString body = Helpers::safeForHtml(messageText);
+
+    QString divStyle = " style=\"color:#00AAEE; font-weight:bold\"";
+    QString nick;
+    if (isMuc)
+    {
+        nick = this->muc->nickName();
+    }
+    else
+    {
+        nick = this->globalObj->getOwnNickname();
+    }
+
+    nick = Helpers::safeForHtml(nick);
+    QString logMessage = "<div" + divStyle + ">"
+                         "<b>[" + QTime::currentTime().toString() + "]</b> ";
+
+
+    if (body.startsWith("/me "))
+    {
+        body.remove(0, 4);
+        logMessage.append("<i>*" + nick + " " + body + "</i>");
+    }
+    else
+    {
+        logMessage.append("<i>&lt;" + nick + "&gt;</i> " + body);
+    }
+
+    logMessage.append("</div>");
+
+
+    this->chatBrowser->append(logMessage);
+}
+
+
+
 void ChatWidget::sendMessage()
 {
     QString msg = this->messageLineEdit->text().trimmed();
@@ -259,7 +298,7 @@ void ChatWidget::sendMessage()
         }
         else
         {
-            xmppClient->sendMessage(this->contactJid, msg);
+            this->globalObj->sendPrivateMessage(this->contactJid, msg);
         }
 
         this->messageLineEdit->clear();
