@@ -1,6 +1,6 @@
 /*
  *   This file is part of AkariXB
- *   Copyright 2015-2016  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2015-2018  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -24,11 +24,11 @@
 CommandHandler::CommandHandler(GlobalObject *globalObject,
                                QObject *parent) : QObject(parent)
 {
-    this->globalObj = globalObject;
+    m_globalObject = globalObject;
 
-    this->xmppClient = this->globalObj->getXmppClient();
-    this->mucManager = this->globalObj->getMucManager();
-    this->varParser = this->globalObj->getVariableParser();
+    m_xmppClient = m_globalObject->getXmppClient();
+    m_mucManager = m_globalObject->getMucManager();
+    m_variableParser = m_globalObject->getVariableParser();
 
 
     // Give seed based on current time to random number generator
@@ -56,13 +56,13 @@ CommandHandler::~CommandHandler()
 void CommandHandler::processCommand(QXmppMessage message)
 {
     QStringList from = message.from().split("/");
-    QString bareFrom = from.takeFirst();
+    const QString bareFrom = from.takeFirst();
 
     QVariantMap commandReply;
 
 
     int userAccessLevel = 0;
-    if (this->globalObj->getAdminJids().contains(bareFrom))
+    if (m_globalObject->getAdminJids().contains(bareFrom))
     {
         userAccessLevel = 100; // Admins get level 100
     }
@@ -70,31 +70,30 @@ void CommandHandler::processCommand(QXmppMessage message)
     if (message.type() == QXmppMessage::GroupChat)
     {
         // Find the matching room object
-        QXmppMucRoom *room = this->globalObj->roomFromJid(bareFrom);
+        QXmppMucRoom *room = m_globalObject->roomFromJid(bareFrom);
         if (room)
         {
-            QString fromNick = from.join("/");
+            const QString fromNick = from.join("/");
             if (fromNick == room->nickName()) // Command from ourselves!
             {
                 return;
             }
 
             // FIXME: log only if it's a recognized command?
-            this->globalObj->addToLog(tr("Command from %1 in room %2: %3")
-                                      .arg(fromNick)
-                                      .arg(bareFrom)
-                                      .arg(message.body()));
+            m_globalObject->addToLog(tr("Command from %1 in room %2: %3")
+                                     .arg(fromNick)
+                                     .arg(bareFrom)
+                                     .arg(message.body()));
 
             commandReply = this->parseCommand(message.body(),
                                               userAccessLevel);
-            QString reply = commandReply.value("replyString").toString();
+            const QString reply = commandReply.value("replyString").toString();
             bool privateReply = commandReply.value("privateReply").toBool();
             if (!reply.isEmpty())
             {
                 if (privateReply)
                 {
-                    // FIXME: add the sent message to ChatWidget in ChatModule
-                    xmppClient->sendMessage(message.from(), reply);
+                    m_globalObject->sendPrivateMessage(message.from(), reply);
                 }
                 else
                 {
@@ -105,19 +104,18 @@ void CommandHandler::processCommand(QXmppMessage message)
     }
     else // Any other type; Error type is handled before entering this method
     {
-        this->globalObj->addToLog(tr("Command from %1: %2")
-                                  .arg(message.from())
-                                  .arg(message.body()));
+        m_globalObject->addToLog(tr("Command from %1: %2")
+                                 .arg(message.from())
+                                 .arg(message.body()));
 
         // TODO: handle per-user flood
 
         commandReply = this->parseCommand(message.body(),
                                           userAccessLevel);
-        QString reply = commandReply.value("replyString").toString();
+        const QString reply = commandReply.value("replyString").toString();
         if (!reply.isEmpty())
         {
-            // FIXME: add the sent message to ChatWidget in ChatModule
-            xmppClient->sendMessage(message.from(), reply);
+            m_globalObject->sendPrivateMessage(message.from(), reply);
         }
     }
 }
@@ -131,40 +129,41 @@ void CommandHandler::processCommand(QXmppMessage message)
 QVariantMap CommandHandler::parseCommand(QString commandString, int userAccess)
 {
     // Remove prefix
-    commandString.remove(0, this->globalObj->getCommandPrefix().length());
+    commandString.remove(0, m_globalObject->getCommandPrefix().length());
 
     QStringList commandStringList = commandString.split(" ");
 
-    QString command = commandStringList.takeFirst(); // FIXME: to lowercase?
+    const QString command = commandStringList.takeFirst(); // FIXME: to lowercase?
     QString parameters = commandStringList.join(" ").trimmed();
 
 
-    QString commandFailedString = tr("The command failed.");
+    const QString commandFailedString = tr("The command failed.");
     QString commandReply;
     QString outputPattern;
     bool privateReply = false; // Initialize for the hardcoded commands
 
 
-    if (command == "help")
+    if (command == QStringLiteral("help"))
     {
         if (parameters.isEmpty())
         {
             // FIXME: Make translatable, but ensure "commands" and "help" aren't
-            commandReply = QString("Use %1commands to list "
-                                   "the available commands.")
-                           .arg(globalObj->getCommandPrefix())
+            commandReply = tr("Use %1 to list the available commands.")
+                           .arg(m_globalObject->getCommandPrefix()
+                                + QStringLiteral("commands"))
                            + "\n\n"
-                           + QString("Use %1help [command] to get help "
-                                     "about a specific command.")
-                           .arg(globalObj->getCommandPrefix());
+                           + tr("Use %1 [command] to get help "
+                                "about a specific command.")
+                             .arg(m_globalObject->getCommandPrefix()
+                                  + QStringLiteral("help"));
         }
         else
         {
             QString query = parameters.trimmed();
             QString helpMessage;
-            foreach (QVariant mapVariant, this->commandDataList)
+            foreach (QVariant mapVariant, m_commandDataList)
             {
-                QVariantMap map = mapVariant.toMap();
+                const QVariantMap map = mapVariant.toMap();
                 if (map.value("trigger").toString() == query)
                 {
                     // Show help only if user is allowed to use this command
@@ -188,42 +187,42 @@ QVariantMap CommandHandler::parseCommand(QString commandString, int userAccess)
             }
         }
     }
-    else if (command == "commands")
+    else if (command == QStringLiteral("commands"))
     {
-        QStringList availableCommands = this->getCommandList(userAccess);
+        const QStringList availableCommands = this->getCommandList(userAccess);
 
         commandReply = tr("Available commands")
-                       + ":\n > ";
+                       + ":\n>    ";
         foreach (QString trigger, availableCommands)
         {
-            commandReply.append(trigger + ", ");
+            commandReply.append(QString("%1,   ").arg(trigger));
         }
 
-        commandReply.remove(-2, 2); // Remove last comma and space
+        commandReply.remove(-4, 4); // Remove last comma and space
     }
-    else if (command == "version")
+    else if (command == QStringLiteral("version"))
     {
         commandReply = QString("AkariXB v%1").arg(qApp->applicationVersion());
     }
-    else if (command == "date")
+    else if (command == QStringLiteral("date"))
     {
         commandReply = QDateTime::currentDateTime()
                                  .toLocalTime()
                                  .toString(Qt::SystemLocaleLongDate);
     }
-    else
+    else //////////////////////////////////////////////// User-defined commands
     {
-        foreach (QVariant mapVariant, this->commandDataList)
+        foreach (QVariant mapVariant, m_commandDataList)
         {
-            QVariantMap map = mapVariant.toMap();
+            const QVariantMap map = mapVariant.toMap();
             if (map.value("trigger").toString() == command)
             {
                 if (userAccess < map.value("accessLevel").toInt())
                 {
                     // FIXME: user JID should be shown here -- a previous log message shows the JID, though.
-                    this->globalObj->addToLog(tr("Command %1 requested without "
-                                                 "the right access level.")
-                                              .arg("'" + command + "'"));
+                    m_globalObject->addToLog(tr("Command %1 requested without "
+                                                "the right access level.")
+                                             .arg("'" + command + "'"));
 
                     qDebug() << "Command" << command
                              << "requested without privileges!";
@@ -235,7 +234,7 @@ QVariantMap CommandHandler::parseCommand(QString commandString, int userAccess)
                 privateReply = map.value("privateReply").toBool();
 
 
-                int commandType = map.value("type").toInt();
+                const int commandType = map.value("type").toInt();
                 if (commandType == 0)
                 {
                     commandReply = map.value("staticReply").toString();
@@ -268,11 +267,11 @@ QVariantMap CommandHandler::parseCommand(QString commandString, int userAccess)
                     }
                     else
                     {
-                        this->globalObj->addToLog(tr("Error loading file %1 "
-                                                     "for command: %2")
-                                                  .arg(map.value("filename")
-                                                          .toString())
-                                                  .arg(command));
+                        m_globalObject->addToLog(tr("Error loading file %1 "
+                                                    "for command: %2")
+                                                 .arg(map.value("filename")
+                                                         .toString())
+                                                 .arg(command));
                         commandReply = commandFailedString;
                     }
                 }
@@ -280,11 +279,21 @@ QVariantMap CommandHandler::parseCommand(QString commandString, int userAccess)
                 {
                     if (parameters.trimmed().isEmpty())
                     {
-                        commandReply = tr("I need a parameter for the query.");
+                        commandReply = tr("I need a parameter for the query:");
+
+                        const QStringList keywords = map.value("keywords")
+                                                        .toMap().keys();
+                        commandReply.append("\n>    ");
+                        foreach (QString keyword, keywords)
+                        {
+                            commandReply.append(QString("%1,   ").arg(keyword));
+                        }
+                        commandReply.remove(-4, 4); // Remove last comma
                     }
                     else
                     {
-                        QVariantMap replies = map.value("keywords").toMap();
+                        const QVariantMap replies = map.value("keywords")
+                                                       .toMap();
 
                         // Keywords are lowercase
                         parameters = parameters.toLower().trimmed();
@@ -301,42 +310,78 @@ QVariantMap CommandHandler::parseCommand(QString commandString, int userAccess)
                 }
                 else if (commandType == 4)
                 {
-                    // FIXME: This is blocking; should run the process in non-blocking mode
+                    const QVariantMap programToRun = map.value("programToRun")
+                                                        .toMap();
 
+                    QString commandLine = programToRun.value("commandLine")
+                                                      .toString().trimmed();
                     QProcess programProcess;
-                    programProcess.start(map.value("programToRun").toString());
-                    if (!programProcess.waitForFinished())
+                    if (programToRun.value("detached").toInt() == 1) // Detached
                     {
-                        commandReply = commandFailedString;
-                    }
-                    else
-                    {
-                        commandReply = QString::fromUtf8(programProcess
-                                                         .readAllStandardOutput()
-                                                         .trimmed());
-
-                        // Nothing on stdout, read stderr
-                        if (commandReply.isEmpty())
+                        if (programProcess.startDetached(commandLine))
                         {
-                            commandReply = QString::fromUtf8(programProcess
-                                                             .readAllStandardError()
-                                                             .trimmed());
+                            commandReply = tr("Started detached program "
+                                              "successfully.");
+                            qDebug() << "Started detached process:"
+                                     << commandLine;
                         }
-
-                        // Still empty...
-                        if (commandReply.isEmpty())
+                        else
                         {
-                            commandReply = tr("Command gave no output text.");
+                            commandReply = commandFailedString;
+                            qDebug() << "Could NOT START detached process:"
+                                     << commandLine;
+                        }
+                    }
+                    else // = 0, wait for it to finish
+                    {
+                        programProcess.start(commandLine);
+                        if (programProcess.waitForStarted())
+                        {
+                            qDebug() << "Started process:"
+                                     << programProcess.program();
+
+                            if (programProcess.waitForFinished(10000)) // Up to 10 secs; FIXME
+                            {
+                                commandReply = QString::fromUtf8(programProcess
+                                                                 .readAllStandardOutput()
+                                                                 .trimmed());
+
+                                // Nothing on stdout, read stderr
+                                if (commandReply.isEmpty())
+                                {
+                                    commandReply = QString::fromUtf8(programProcess
+                                                                     .readAllStandardError()
+                                                                     .trimmed());
+                                }
+
+                                // Still empty...
+                                if (commandReply.isEmpty())
+                                {
+                                    commandReply = tr("Command gave no output text.");
+                                }
+                            }
+                            else
+                            {
+                                commandReply = commandFailedString;
+                                qDebug() << "Took more than allowed time to complete!";
+                            }
+                        }
+                        else
+                        {
+                            commandReply = commandFailedString;
+                            qDebug() << "Could NOT START process:"
+                                     << programProcess.program()
+                                     << programProcess.errorString();
                         }
                     }
                 }
                 else if (commandType == 5)
                 {
-                    QString aliasFor = map.value("aliasFor").toString();
+                    const QString aliasFor = map.value("aliasFor").toString();
 
-                    QString aliasCommand = this->globalObj->getCommandPrefix()
-                                           + aliasFor
-                                           + parameters;
+                    const QString aliasCommand = m_globalObject->getCommandPrefix()
+                                                 + aliasFor
+                                                 + parameters;
                     qDebug() << "This is an alias for:" << aliasFor;
 
                     // Protection againt infinite recursivity
@@ -364,8 +409,8 @@ QVariantMap CommandHandler::parseCommand(QString commandString, int userAccess)
         commandReply = outputPattern;
     }
 
-    // Parse things like %line%, random choices in {a|b|c}, etc
-    commandReply = this->varParser->getParsed(commandReply);
+    // Parse and replace things like %line%, random choices in {a|b|c}, etc
+    commandReply = m_variableParser->getParsed(commandReply);
 
     QVariantMap replyMap;
     replyMap.insert("replyString", commandReply);
@@ -378,14 +423,14 @@ QVariantMap CommandHandler::parseCommand(QString commandString, int userAccess)
 void CommandHandler::setCommandData(QVariantList dataList)
 {
     //qDebug() << "Sync'ing command data:\n\n" << dataList;
-    this->commandDataList = dataList;
+    m_commandDataList = dataList;
 }
 
 
 QStringList CommandHandler::getCommandList(int accessLevel)
 {
     QStringList list;
-    foreach (QVariant mapVariant, this->commandDataList)
+    foreach (QVariant mapVariant, m_commandDataList)
     {
         if (mapVariant.toMap().value("accessLevel").toInt() <= accessLevel)
         {
