@@ -1,6 +1,6 @@
 /*
  *   This file is part of AkariXB
- *   Copyright 2015-2016  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2015-2018  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -66,6 +66,7 @@ CommandModule::CommandModule(CommandHandler *handler,
 
     // Right side
     this->triggerLineEdit = new QLineEdit(this);
+    triggerLineEdit->setPlaceholderText(tr("The name, without the prefix"));
     connect(triggerLineEdit, SIGNAL(textChanged(QString)),
             this, SLOT(onTriggerChanged(QString)));
 
@@ -92,13 +93,19 @@ CommandModule::CommandModule(CommandHandler *handler,
                              "corresponding definition for each keyword on "
                              "the other side."));
     typeCombobox->addItem(tr("Run Program"),
-                          tr("Enter a command to be run, with any needed "
-                             "parameters.\n"
+                          tr("Enter a system command line to be run, with "
+                             "any needed parameters.\n"
                              "The reply will be the console output of the "
-                             "program, unless you specify an output pattern, "
+                             "program, unless you specify a reply pattern, "
                              "and don't include the %output% variable "
                              "somewhere in it.",
-                             "Don't translate %output%!"));
+                             "Don't translate %output%!")
+                          + "\n\n"
+                          + tr("If the program you launch will take a long "
+                               "time to finish (like a GUI), you need to "
+                               "select the option to launch it independently, "
+                               "but then it will not be possible to use the "
+                               "program output as the reply for the command."));
     typeCombobox->addItem(tr("Alias for another command"),
                           tr("Enter the original command that should be run "
                              "when this alias is used."));
@@ -122,6 +129,9 @@ CommandModule::CommandModule(CommandHandler *handler,
     this->randomListWidget = new StringListWidget(false, this);
 
     this->filenameLabel = new QLabel(this);
+    QFont filenameFont = filenameLabel->font();
+    filenameFont.setBold(true);
+    filenameLabel->setFont(filenameFont);
     this->filenameButton = new QPushButton(QIcon::fromTheme("document-open",
                                                             QIcon(":/images/button-edit.png")),
                                            tr("Select File..."),
@@ -137,14 +147,21 @@ CommandModule::CommandModule(CommandHandler *handler,
     keywordListWidget->setLowercaseItems(true);
 
 
-    this->programLineEdit = new QLineEdit(this);
+    m_programLineEdit = new QLineEdit(this);
+    m_runDetachedCombobox = new QComboBox(this);
+    m_runDetachedCombobox->addItem(tr("Wait for the program to finish"));
+    m_runDetachedCombobox->addItem(tr("Launch the program independently"));
+    m_programLayout = new QHBoxLayout();
+    m_programLayout->addWidget(m_programLineEdit);
+    m_programLayout->addWidget(m_runDetachedCombobox);
+
 
     this->aliasLineEdit = new QLineEdit(this);
 
 
     this->outputLineEdit = new QLineEdit(this);
-    this->outputLineEdit->setPlaceholderText(tr("Optional, like: "
-                                                "[RESULT] %line% %output%"));
+    this->outputLineEdit->setPlaceholderText(tr("Optional, like: [RESULT]")
+                                             + " %line%--- %output% ---");
 
     this->privateReplyCheckbox = new QCheckBox(this);
 
@@ -173,7 +190,7 @@ CommandModule::CommandModule(CommandHandler *handler,
     typeLayout->addWidget(randomListWidget);
     typeLayout->addLayout(filenameLayout);
     typeLayout->addWidget(keywordListWidget);
-    typeLayout->addWidget(programLineEdit);
+    typeLayout->addLayout(m_programLayout);
     typeLayout->addWidget(aliasLineEdit);
 
 
@@ -183,8 +200,8 @@ CommandModule::CommandModule(CommandHandler *handler,
     formLayout->addRow(tr("Access Level"),    accessLevelSpinbox);
     formLayout->addRow(tr("Type"),            typeCombobox);
     formLayout->addWidget(typeHelpLabel);
-    formLayout->addRow("", typeLayout);
-    formLayout->addRow(tr("Output Pattern"),  outputLineEdit);
+    formLayout->addRow(QString(), typeLayout);
+    formLayout->addRow(tr("Reply Pattern"),   outputLineEdit);
     formLayout->addRow(tr("Private Reply"),   privateReplyCheckbox);
 
 
@@ -330,10 +347,10 @@ bool CommandModule::validateCommand(int commandType)
     }
     else if (commandType == 4)
     {
-        if (this->programLineEdit->text().trimmed().isEmpty())
+        if (m_programLineEdit->text().trimmed().isEmpty())
         {
             errorMessage = tr("There is no program specified.");
-            this->programLineEdit->setFocus();
+            m_programLineEdit->setFocus();
         }
     }
     else if (commandType == 5)
@@ -453,7 +470,8 @@ void CommandModule::onCommandSelected(int row)
     this->filenameLabel->setText("[" + tr("No file selected") + "]");
     this->textFilename.clear();
     this->keywordListWidget->clearList();
-    this->programLineEdit->clear();
+    m_programLineEdit->clear();
+    m_runDetachedCombobox->setCurrentIndex(0);
     this->aliasLineEdit->clear();
 
 
@@ -474,12 +492,16 @@ void CommandModule::onCommandSelected(int row)
     }
     else if (commandType == 3)
     {
-        QVariantMap stringMap = item->data(Qt::UserRole + 4).toMap();
+        const QVariantMap stringMap = item->data(Qt::UserRole + 4).toMap();
         this->keywordListWidget->addItemsToList(stringMap);
     }
     else if (commandType == 4)
     {
-        this->programLineEdit->setText(item->data(Qt::UserRole + 4).toString());
+        const QVariantMap programMap = item->data(Qt::UserRole + 4).toMap();
+        m_programLineEdit->setText(programMap.value("commandLine")
+                                             .toString());
+        m_runDetachedCombobox->setCurrentIndex(programMap.value("detached")
+                                                         .toInt());
     }
     else if (commandType == 5)
     {
@@ -506,7 +528,8 @@ void CommandModule::onTypeChanged(int commandType)
     this->filenameLabel->hide();
     this->filenameButton->hide();
     this->keywordListWidget->hide();
-    this->programLineEdit->hide();
+    m_programLineEdit->hide();
+    m_runDetachedCombobox->hide();
     this->aliasLineEdit->hide();
 
 
@@ -529,7 +552,8 @@ void CommandModule::onTypeChanged(int commandType)
     }
     else if (commandType == 4)
     {
-        this->programLineEdit->show();
+        m_programLineEdit->show();
+        m_runDetachedCombobox->show();
     }
     else if (commandType == 5)
     {
@@ -554,7 +578,7 @@ void CommandModule::saveCommand()
                 QMessageBox::warning(this,
                                      tr("Command exists"),
                                      tr("Error: There is already a command "
-                                        "in the list with this trigger."));
+                                        "in the list with this name."));
                 this->triggerLineEdit->setFocus();
 
                 return;
@@ -601,8 +625,11 @@ void CommandModule::saveCommand()
     }
     else if (commandType == 4)
     {
-        item->setData(Qt::UserRole + 4,
-                      this->programLineEdit->text().trimmed());
+        QVariantMap programMap;
+        programMap.insert("commandLine", m_programLineEdit->text().trimmed());
+        programMap.insert("detached", m_runDetachedCombobox->currentIndex());
+
+        item->setData(Qt::UserRole + 4, programMap);
     }
     else if (commandType == 5)
     {
@@ -630,10 +657,12 @@ void CommandModule::syncCommands()
     for (int counter = 0; counter < commandListWidget->count(); ++counter)
     {
         QListWidgetItem *item = commandListWidget->item(counter);
-        int commandType = item->data(Qt::UserRole + 3).toInt();
+        const int commandType = item->data(Qt::UserRole + 3).toInt();
+        const QString commandTrigger = item->data(Qt::UserRole).toString()
+                                                               .trimmed();
 
         QVariantMap commandMap;
-        commandMap.insert("trigger",     item->data(Qt::UserRole));
+        commandMap.insert("trigger",     commandTrigger);
         commandMap.insert("helpText",    item->data(Qt::UserRole + 1));
         commandMap.insert("accessLevel", item->data(Qt::UserRole + 2));
         commandMap.insert("type",        commandType);
@@ -666,14 +695,19 @@ void CommandModule::syncCommands()
         commandMap.insert("outputPattern", item->data(Qt::UserRole + 5));
         commandMap.insert("privateReply",  item->data(Qt::UserRole + 6));
 
-        commandDataList.append(commandMap);
+        // Avoid the possibility of saving empty commands
+        if (!commandTrigger.isEmpty())
+        {
+            commandDataList.append(commandMap);
+        }
     }
 
 
     this->commandHandler->setCommandData(commandDataList);
     this->dataFile->saveData(commandDataList);
 
-    this->globalObj->addToLog(tr("Saved %Ln command(s).", "",
-                              commandDataList.length()));
+    this->globalObj->addToLog(tr("Saved %Ln command(s).",
+                                 "",
+                                 commandDataList.length()));
 }
 
