@@ -1,6 +1,6 @@
 /*
  *   This file is part of AkariXB
- *   Copyright 2015-2016  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2015-2018  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -108,7 +108,11 @@ private:
     QPushButton *filenameButton;
 
     StringListWidget *keywordListWidget;
-    QLineEdit *programLineEdit;
+
+    QHBoxLayout *m_programLayout;
+    QLineEdit *m_programLineEdit;
+    QComboBox *m_runDetachedCombobox;
+
     QLineEdit *aliasLineEdit;
 
     QLineEdit *outputLineEdit;
