@@ -1,6 +1,6 @@
 /*
  *   This file is part of AkariXB
- *   Copyright 2015-2016  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2015-2018  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -41,11 +41,17 @@ ConfigDialog::ConfigDialog(GlobalObject *globalObject,
     this->commandPrefixLineEdit = new QLineEdit(globalObj->getCommandPrefix(),
                                                 this);
 
-    this->keepAliveSpinbox = new QSpinBox(this);
-    keepAliveSpinbox->setRange(20, 600);
-    keepAliveSpinbox->setSuffix(" " + tr("seconds",
+    this->keepAliveTimeoutSpinbox = new QSpinBox(this);
+    keepAliveTimeoutSpinbox->setRange(20, 600);
+    keepAliveTimeoutSpinbox->setSuffix(" " + tr("seconds",
                                          "Suffix next to a number"));
-    keepAliveSpinbox->setValue(globalObj->getKeepAliveTimeout());
+    keepAliveTimeoutSpinbox->setValue(globalObj->getKeepAliveTimeout());
+
+    this->keepAliveIntervalSpinbox = new QSpinBox(this);
+    keepAliveIntervalSpinbox->setRange(30, 9999);
+    keepAliveIntervalSpinbox->setSuffix(" " + tr("seconds",
+                                         "Suffix next to a number"));
+    keepAliveIntervalSpinbox->setValue(globalObj->getKeepAliveInterval());
 
 
     this->generalOptionsLayout = new QFormLayout();
@@ -54,7 +60,9 @@ ConfigDialog::ConfigDialog(GlobalObject *globalObject,
     generalOptionsLayout->addRow(tr("Command prefix"),
                                  commandPrefixLineEdit);
     generalOptionsLayout->addRow(tr("Connection timeout"),
-                                 keepAliveSpinbox);
+                                 keepAliveTimeoutSpinbox);
+    generalOptionsLayout->addRow(tr("Connection ping interval"),
+                                 keepAliveIntervalSpinbox);
 
 
     this->generalOptionsWidget = new QWidget(this);
@@ -81,8 +89,7 @@ ConfigDialog::ConfigDialog(GlobalObject *globalObject,
 
     // Tab 3: System tray options
     this->hideWindowCheckbox = new QCheckBox(this);
-    hideWindowCheckbox->setDisabled(true); // TMP, FIXME: until implemented
-
+    hideWindowCheckbox->setChecked(globalObj->getHideInTray());
 
     this->systrayOptionsLayout = new QFormLayout();
     systrayOptionsLayout->addRow(tr("Hide window on startup"),
@@ -173,10 +180,13 @@ void ConfigDialog::saveSettings()
     settings.setValue("commandPrefix",
                       this->commandPrefixLineEdit->text().trimmed());
     settings.setValue("keepaliveTimeout",
-                      this->keepAliveSpinbox->value());
+                      this->keepAliveTimeoutSpinbox->value());
+    settings.setValue("keepaliveInterval",
+                      this->keepAliveIntervalSpinbox->value());
     this->globalObj->syncGeneralSettings(this->adminJidListWidget->getStringsFromList(),
                                          this->commandPrefixLineEdit->text().trimmed(),
-                                         this->keepAliveSpinbox->value());
+                                         this->keepAliveTimeoutSpinbox->value(),
+                                         this->keepAliveIntervalSpinbox->value());
 
     settings.setValue("notifyNewChats",
                       this->notifyNewChatsCheckbox->isChecked());
@@ -185,7 +195,9 @@ void ConfigDialog::saveSettings()
     this->globalObj->syncNotificationSettings(this->notifyNewChatsCheckbox->isChecked(),
                                               this->notifyDisconnectionCheckbox->isChecked());
 
-    this->globalObj->syncSystraySettings();
+    settings.setValue("hideInTray",
+                      this->hideWindowCheckbox->isChecked());
+    this->globalObj->syncSystraySettings(this->hideWindowCheckbox->isChecked());
 
 
     settings.endGroup();
