@@ -1,6 +1,6 @@
 /*
  *   This file is part of AkariXB
- *   Copyright 2015-2016  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2015-2018  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -65,7 +65,8 @@ private:
     QFormLayout *generalOptionsLayout;
     StringListWidget *adminJidListWidget;
     QLineEdit *commandPrefixLineEdit;
-    QSpinBox *keepAliveSpinbox;
+    QSpinBox *keepAliveTimeoutSpinbox;
+    QSpinBox *keepAliveIntervalSpinbox;
 
 
     QWidget *notificationOptionsWidget;
