@@ -1,6 +1,6 @@
 /*
  *   This file is part of AkariXB
- *   Copyright 2015-2016  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2015-2018  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -25,16 +25,7 @@
 #include <QFile>
 #include <QVariantMap>
 #include <QVariantList>
-
-// For JSON
-#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
-// Qt 4
-#include <qjson/parser.h>
-#include <qjson/serializer.h>
-#else
-// Qt 5
 #include <QJsonDocument>
-#endif
 
 #include <QDebug>
 
@@ -55,7 +46,7 @@ signals:
 public slots:
 
 private:
-    QFile *dFile;
+    QFile *m_file;
 
 };
 
