@@ -1,6 +1,6 @@
 /*
  *   This file is part of AkariXB
- *   Copyright 2015-2016  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2015-2018  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -60,8 +60,8 @@ GeneralModule::GeneralModule(GlobalObject *globalObject,
     statusMessageLabel->setContentsMargins(4, 4, 4, 4);
     statusMessageLabel->setSizePolicy(QSizePolicy::MinimumExpanding,
                                       QSizePolicy::Minimum);
-    connect(globalObj, SIGNAL(statusMessageChanged(QString)),
-            statusMessageLabel, SLOT(setText(QString)));
+    connect(globalObj, SIGNAL(statusChanged(QXmppPresence)),
+            this, SLOT(onStatusChanged(QXmppPresence)));
 
 
 
@@ -208,3 +208,9 @@ void GeneralModule::onDisconnected()
     this->disconnectButton->hide();
 }
 
+
+void GeneralModule::onStatusChanged(QXmppPresence presence)
+{
+    this->statusMessageLabel->setText(presence.statusText());
+}
+
