@@ -1,6 +1,6 @@
 /*
  *   This file is part of AkariXB
- *   Copyright 2015-2016  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2015-2018  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -33,6 +33,8 @@ GlobalObject::GlobalObject(QObject *parent) : QObject(parent)
                               settings.value("commandPrefix",
                                              "!").toString(),
                               settings.value("keepAliveTimeout",
+                                             60).toInt(),
+                              settings.value("keepAliveInterval",
                                              60).toInt());
 
 
@@ -42,7 +44,8 @@ GlobalObject::GlobalObject(QObject *parent) : QObject(parent)
                                                   false).toBool());
 
 
-    this->syncSystraySettings();
+    this->syncSystraySettings(settings.value("hideInTray",
+                                             false).toBool());
 
 
 
@@ -58,11 +61,13 @@ GlobalObject::~GlobalObject()
 
 void GlobalObject::syncGeneralSettings(QStringList newAdminJids,
                                        QString newCommandPrefix,
-                                       int newKeepAliveTimeout)
+                                       int newKeepAliveTimeout,
+                                       int newKeepAliveInterval)
 {
     this->adminJids = newAdminJids;
     this->commandPrefix = newCommandPrefix;
     this->keepAliveTimeout = newKeepAliveTimeout;
+    this->keepAliveInterval = newKeepAliveInterval;
 }
 
 
@@ -82,6 +87,11 @@ int GlobalObject::getKeepAliveTimeout()
     return this->keepAliveTimeout;
 }
 
+int GlobalObject::getKeepAliveInterval()
+{
+    return this->keepAliveInterval;
+}
+
 
 
 void GlobalObject::syncNotificationSettings(bool forNewChats,
@@ -102,9 +112,14 @@ bool GlobalObject::getNotifyDisconnection()
 }
 
 
-void GlobalObject::syncSystraySettings()
+void GlobalObject::syncSystraySettings(bool hideInTray)
 {
+    this->hideInSystemTray = hideInTray;
+}
 
+bool GlobalObject::getHideInTray()
+{
+    return this->hideInSystemTray;
 }
 
 
@@ -219,6 +234,19 @@ QXmppMucRoom *GlobalObject::roomFromJid(QString roomJid)
 }
 
 
+void GlobalObject::setOwnNickname(QString newNick)
+{
+    this->ownNickname = newNick;
+    this->variableParser->setOwnNickname(newNick);
+}
+
+
+QString GlobalObject::getOwnNickname()
+{
+    return this->ownNickname;
+}
+
+
 void GlobalObject::notifyActivityChange(QString name, QString timeRange)
 {
     QString text = name;
@@ -231,9 +259,9 @@ void GlobalObject::notifyActivityChange(QString name, QString timeRange)
     emit activityChanged(text);
 }
 
-void GlobalObject::notifyStatusMessageChange(QString text)
+void GlobalObject::notifyStatusChange(QXmppPresence presence)
 {
-    emit statusMessageChanged(text);
+    emit statusChanged(presence);
 }
 
 
@@ -257,3 +285,12 @@ void GlobalObject::sendMessageToJid(QString jid, QString message)
     }
 }
 
+
+
+void GlobalObject::sendPrivateMessage(QString jid, QString message)
+{
+    this->xmppClient->sendMessage(jid, message);
+
+    emit privateMessageSent(jid, message);
+}
+
