@@ -1,6 +1,6 @@
 /*
  *   This file is part of AkariXB
- *   Copyright 2015-2016  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2015-2018  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -43,12 +43,12 @@ public:
 
 
     // General settings
-    void syncGeneralSettings(QStringList newAdminJids,
-                             QString newCommandPrefix,
-                             int newKeepAliveTimeout);
+    void syncGeneralSettings(QStringList newAdminJids, QString newCommandPrefix,
+                             int newKeepAliveTimeout, int newKeepAliveInterval);
     QStringList getAdminJids();
     QString getCommandPrefix();
     int getKeepAliveTimeout();
+    int getKeepAliveInterval();
 
     // Notification settings
     void syncNotificationSettings(bool forNewChats,
@@ -57,7 +57,8 @@ public:
     bool getNotifyDisconnection();
 
     // Systray settings
-    void syncSystraySettings();
+    void syncSystraySettings(bool hideInTray);
+    bool getHideInTray();
 
 
     //////////
@@ -91,12 +92,16 @@ public:
 
     QXmppMucRoom *roomFromJid(QString roomJid);
 
+    void setOwnNickname(QString newNick);
+    QString getOwnNickname();
+
 
     void notifyActivityChange(QString name, QString timeRange);
-    void notifyStatusMessageChange(QString text);
+    void notifyStatusChange(QXmppPresence presence);
 
 
     void sendMessageToJid(QString jid, QString message);
+    void sendPrivateMessage(QString jid, QString message);
 
 
 
@@ -106,7 +111,9 @@ signals:
     void showNotificationPopup(QString title, QString message);
 
     void activityChanged(QString activityInfo);
-    void statusMessageChanged(QString text);
+    void statusChanged(QXmppPresence presence);
+
+    void privateMessageSent(QString jid, QString message);
 
 
 public slots:
@@ -125,12 +132,15 @@ private:
 
     QStringList joinedRooms;
 
+    QString ownNickname;
+
 
 
     // General options
     QStringList adminJids;
     QString commandPrefix;
     int keepAliveTimeout;
+    int keepAliveInterval;
 
 
     // Notification options
@@ -139,6 +149,7 @@ private:
 
 
     // Systray options
+    bool hideInSystemTray;
 
 
 };
