@@ -1,6 +1,6 @@
 /*
  *   This file is part of AkariXB
- *   Copyright 2015-2016  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2015-2018  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -83,6 +83,35 @@ QString Helpers::randomString(QStringList stringList)
     return chosenString;
 }
 
+/*
+ * Create a reduced list of strings from a full one
+ *
+ */
+QStringList Helpers::someStrings(QStringList stringList, int percent)
+{
+    if (stringList.isEmpty())
+    {
+        return QStringList();
+    }
+
+    QStringList chosenStrings;
+
+    int minimumCount = (stringList.size() * percent) / 100;
+    minimumCount = qMax(minimumCount, 1);
+
+    int stringCount = 0;
+    while (stringCount < minimumCount)
+    {
+        const QString string = randomString(stringList);
+        chosenStrings.append(string);
+        stringList.removeAll(string);
+
+        ++stringCount;
+    }
+
+    return chosenStrings;
+}
+
 
 /*
  * Random number between 2 numbers
@@ -111,14 +140,13 @@ int Helpers::randomBetween(int lowNum, int highNum)
  */
 bool Helpers::probability(int chancePercent)
 {
-    int randomNumber = qrand() % 100; // Random between 0 and 100
+    const int randomNumber = qrand() % 100; // Random between 0 and 100
 
-    if (randomNumber <= chancePercent)
+    if (randomNumber < chancePercent)
     {
         return true;
     }
 
-
     return false;
 }
 
