@@ -1,6 +1,6 @@
 /*
  *   This file is part of AkariXB
- *   Copyright 2015-2016  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2015-2018  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -25,38 +25,38 @@
 IdentityModule::IdentityModule(GlobalObject *globalObject,
                                QWidget *parent) : QWidget(parent)
 {
-    this->globalObj = globalObject;
+    this->m_globalObject = globalObject;
 
-    this->dataFile = new DataFile(globalObj->getDataDirectory()
-                                  + "/identity.axb",
-                                  this);
+    m_dataFile = new DataFile(m_globalObject->getDataDirectory()
+                              + "/identity.axb",
+                              this);
 
 
-    this->nickLineEdit = new QLineEdit(this); // Multinicks? FIXME
+    m_nickLineEdit = new QLineEdit(this); // Multinicks? -- FIXME
 
     // Add formal name field? Last name fields?
 
 
-    this->updateButton = new QPushButton(QIcon::fromTheme("document-save",
-                                                          QIcon(":/images/button-save.png")),
-                                         tr("&Update"),
-                                         this);
-    connect(updateButton, SIGNAL(clicked()),
-            this, SLOT(updateData()));
+    m_updateButton = new QPushButton(QIcon::fromTheme("document-save",
+                                                      QIcon(":/images/button-save.png")),
+                                     tr("&Update"),
+                                     this);
+    connect(m_updateButton, &QAbstractButton::clicked,
+            this, &IdentityModule::updateData);
 
 
-    this->formLayout = new QFormLayout();
-    formLayout->addRow(tr("Nickname"), nickLineEdit);
+    m_formLayout = new QFormLayout();
+    m_formLayout->addRow(tr("Nickname"), m_nickLineEdit);
 
-    this->mainLayout = new QVBoxLayout();
-    mainLayout->addLayout(formLayout);
-    mainLayout->addStretch(1);
-    mainLayout->addWidget(new QLabel("Formal name,\n"
-                                     "likes and dislikes, etc.", this),
-                          0, Qt::AlignCenter); // TMP-------------------------------
-    mainLayout->addStretch(2);
-    mainLayout->addWidget(updateButton, 0, Qt::AlignRight);
-    this->setLayout(mainLayout);
+    m_mainLayout = new QVBoxLayout();
+    m_mainLayout->addLayout(m_formLayout);
+    m_mainLayout->addStretch(1);
+    m_mainLayout->addWidget(new QLabel("Formal name,\n"
+                                       "likes and dislikes, etc.", this),
+                            0, Qt::AlignCenter); // TMP-------------------------------
+    m_mainLayout->addStretch(2);
+    m_mainLayout->addWidget(m_updateButton, 0, Qt::AlignRight);
+    this->setLayout(m_mainLayout);
 
     this->loadIdentity();
 
@@ -72,7 +72,7 @@ IdentityModule::~IdentityModule()
 
 void IdentityModule::loadIdentity()
 {
-    QVariantList identityDataList = this->dataFile->loadData();
+    const QVariantList identityDataList = m_dataFile->loadData();
 
     QVariantMap identityMap;
     if (!identityDataList.isEmpty())
@@ -85,8 +85,8 @@ void IdentityModule::loadIdentity()
     {
         nickname = "AkariXB"; // Default
     }
-    this->nickLineEdit->setText(nickname);
-    this->globalObj->getVariableParser()->setOwnNickname(nickname);
+    m_nickLineEdit->setText(nickname);
+    m_globalObject->setOwnNickname(nickname);
 
 
     // Load other values, likes list, dislikes list, etc
@@ -94,8 +94,8 @@ void IdentityModule::loadIdentity()
 
     if (!identityDataList.isEmpty())
     {
-        this->globalObj->addToLog(tr("Loaded identity data for %1.",
-                                     "%1 is a nickname").arg(nickname));
+        m_globalObject->addToLog(tr("Loaded identity data for %1.",
+                                    "%1 is a nickname").arg(nickname));
     }
 }
 
@@ -107,14 +107,14 @@ void IdentityModule::loadIdentity()
 
 void IdentityModule::updateData()
 {
-    QString nickname = nickLineEdit->text().trimmed();
+    QString nickname = m_nickLineEdit->text().trimmed();
     if (nickname.isEmpty())
     {
         nickname = "AkariXB";  // Default
-        nickLineEdit->setText(nickname);
+        m_nickLineEdit->setText(nickname);
     }
 
-    this->globalObj->getVariableParser()->setOwnNickname(nickname);
+    m_globalObject->setOwnNickname(nickname);
 
 
     QVariantMap identityMap;
@@ -124,9 +124,9 @@ void IdentityModule::updateData()
 
     QVariantList identityDataList;
     identityDataList.append(identityMap);
-    this->dataFile->saveData(identityDataList);
+    m_dataFile->saveData(identityDataList);
 
-    this->globalObj->addToLog(tr("Saved identity data for %1.",
-                                 "%1 is a nickname").arg(nickname));
+    m_globalObject->addToLog(tr("Saved identity data for %1.",
+                                "%1 is a nickname").arg(nickname));
 }
 
