@@ -1,6 +1,6 @@
 /*
  *   This file is part of AkariXB
- *   Copyright 2015-2016  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2015-2018  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -27,20 +27,8 @@
 #include "mainwindow.h"
 
 
-
-#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
-void customMessageHandlerQt4(QtMsgType type, const char *msg)
-{
-    // do nothing
-    Q_UNUSED(type)
-    Q_UNUSED(msg)  // FIXME, memory leak?
-
-    return;
-}
-#else
-void customMessageHandlerQt5(QtMsgType type,
-                             const QMessageLogContext &context,
-                             const QString &msg)
+void customMessageHandler(QtMsgType type, const QMessageLogContext &context,
+                          const QString &msg)
 {
     Q_UNUSED(type)
     Q_UNUSED(context)
@@ -50,7 +38,6 @@ void customMessageHandlerQt5(QtMsgType type,
 
     return;
 }
-#endif
 
 
 
@@ -58,13 +45,14 @@ int main(int argc, char *argv[])
 {
     QApplication akariApp(argc, argv);
     akariApp.setApplicationName("AkariXB");
-    akariApp.setApplicationVersion("0.4");
+    akariApp.setApplicationVersion("0.5");
     akariApp.setOrganizationName("JanCoding");
     akariApp.setOrganizationDomain("jancoding.wordpress.com");
 
-    std::cout << QString("AkariXB v%1 - JanKusanagi 2015-2016\n"
+    std::cout << QString("AkariXB v%1 - JanKusanagi 2015-2018\n"
                          "https://jancoding.wordpress.com/akarixb\n\n")
-                        .arg(akariApp.applicationVersion()).toStdString();
+                 .arg(akariApp.applicationVersion())
+                 .toStdString();
 
     std::cout << QString("- Built with Qt v%1").arg(QT_VERSION_STR)
                                                .toStdString();
@@ -175,11 +163,7 @@ int main(int argc, char *argv[])
 
         std::cout << "To see debug messages while running, use --debug\n";
 
-#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
-        qInstallMsgHandler(customMessageHandlerQt4);
-#else
-        qInstallMessageHandler(customMessageHandlerQt5);
-#endif
+        qInstallMessageHandler(customMessageHandler);
     }
 
 
@@ -239,7 +223,7 @@ int main(int argc, char *argv[])
 
 
     MainWindow akariWindow;
-    akariWindow.toggleMainWindow();
+    akariWindow.toggleMainWindow(true); // onStartup=true
 
 
     return akariApp.exec();
