@@ -1,6 +1,6 @@
 /*
  *   This file is part of AkariXB
- *   Copyright 2015-2016  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2015-2018  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -52,6 +52,11 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
 
     // Page 8, runtime log, needed before others for early logging
     this->logModule = new LogModule(this);
+    logModule->addToLog(QString("Qt v%1 (%2), QXMPP v%3, %4.")
+                        .arg(qVersion(),
+                             qApp->platformName(),
+                             QXmppVersion(),
+                             QSysInfo::prettyProductName()));
     connect(globalObject, SIGNAL(logMessage(QString)),
             logModule, SLOT(addToLog(QString)));
 
@@ -109,7 +114,7 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
     categoriesList->addItem(tr("Rooms"));
     categoriesList->item(1)->setIcon(QIcon::fromTheme("system-users",
                                                       QIcon(":/images/section-rooms.png")));
-    categoriesList->addItem("*chats*");
+    categoriesList->addItem(QString()); // Chats, title set later
     categoriesList->item(2)->setIcon(QIcon::fromTheme("system-users",
                                                       QIcon(":/images/section-rooms.png")));
     this->setChatsTitle(0);
@@ -181,7 +186,10 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
 
     if (this->userJid.isEmpty())
     {
-        connectionDialog->show();
+        if (!this->globalObject->getHideInTray())
+        {
+            connectionDialog->show();
+        }
     }
     else if (this->userAutoconnect)
     {
@@ -270,15 +278,22 @@ void MainWindow::createMenus()
     connect(helpBugTrackerAction, SIGNAL(triggered()),
             this, SLOT(visitBugTracker()));
 
+    this->helpAboutXmppAction = new QAction(QIcon::fromTheme("internet-web-browser"),
+                                            tr("About XMPP"),
+                                            this);
+    connect(helpAboutXmppAction, SIGNAL(triggered()),
+            this, SLOT(visitXmppOrg()));
+
     this->helpAboutAction = new QAction(QIcon(":/icon/64x64/akarixb.png"),
-                                    tr("About AkariXB"),
-                                    this);
+                                        tr("About AkariXB"),
+                                        this);
     connect(helpAboutAction, SIGNAL(triggered()),
             this, SLOT(aboutAkariXB()));
 
     this->helpMenu = new QMenu(tr("&Help"), this);
     helpMenu->addAction(helpWebsiteAction);
     helpMenu->addAction(helpBugTrackerAction);
+    helpMenu->addAction(helpAboutXmppAction);
     helpMenu->addSeparator();
     helpMenu->addAction(helpAboutAction);
     this->menuBar()->addMenu(helpMenu);
@@ -347,7 +362,9 @@ void MainWindow::createTrayIcon()
 void MainWindow::createStatusBarWidgets()
 {
     this->statusBarLabel = new QLabel(this);
-    this->setStatusIconOnline(false);
+    this->setStatusIconOnline(QXmppPresence::Online, false);
+    connect(globalObject, SIGNAL(statusChanged(QXmppPresence)),
+            this, SLOT(onStatusChanged(QXmppPresence)));
 
     this->statusBar()->addPermanentWidget(statusBarLabel);
     this->statusBar()->setSizeGripEnabled(false);
@@ -358,12 +375,8 @@ void MainWindow::createStatusBarWidgets()
 void MainWindow::createDataDir()
 {
     QString dataDirectory;
-
-#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
-    dataDirectory = QDesktopServices::storageLocation(QDesktopServices::DataLocation);
-#else
-    dataDirectory = QStandardPaths::standardLocations(QStandardPaths::DataLocation).first();
-#endif
+    dataDirectory = QStandardPaths::standardLocations(QStandardPaths::DataLocation)
+                                   .first();
 
     this->globalObject->setDataDirectory(dataDirectory);
     qDebug() << "Data directory:" << dataDirectory;
@@ -410,7 +423,7 @@ void MainWindow::createDataDir()
 void MainWindow::setupXmppClient()
 {
     this->xmppClient = new QXmppClient(this);
-    xmppClient->configuration().setKeepAliveTimeout(this->globalObject->getKeepAliveTimeout());
+    xmppClient->versionManager().setClientName("AkariXB");
     xmppClient->versionManager().setClientOs("Akari-GNU-OS"); // tmp FIXME xD
 
 #if 0  // Verbose XMPP console
@@ -437,6 +450,9 @@ void MainWindow::setupXmppClient()
     this->mucManager = new QXmppMucManager();
     xmppClient->addExtension(mucManager);
 
+    this->receiptManager = new QXmppMessageReceiptManager();
+    xmppClient->addExtension(receiptManager);
+
 
     this->globalObject->setXmppClient(this->xmppClient);
     this->globalObject->setMucManager(this->mucManager);
@@ -491,18 +507,42 @@ void MainWindow::saveSettings()
 }
 
 
-void MainWindow::setStatusIconOnline(bool state)
+void MainWindow::setStatusIconOnline(QXmppPresence::AvailableStatusType statusType,
+                                     bool isOnline)
 {
-    if (state)
+    QString iconFile;
+
+    if (isOnline)
     {
-        statusBarLabel->setPixmap(QPixmap(":/images/button-online.png")
-                                  .scaled(16, 16));
+        switch (statusType)
+        {
+        case QXmppPresence::Online:
+            iconFile = ":/images/button-online.png";
+            break;
+
+        case QXmppPresence::Away:
+            iconFile = ":/images/button-away.png";
+            break;
+
+        case QXmppPresence::XA:
+            iconFile = ":/images/button-xa.png";
+            break;
+
+        case QXmppPresence::DND:
+            iconFile = ":/images/button-dnd.png";
+            break;
+
+        default:
+            iconFile = ":/images/button-online.png";
+            break;
+        }
     }
     else
     {
-        statusBarLabel->setPixmap(QPixmap(":/images/button-offline.png")
-                                  .scaled(16, 16));
+        iconFile = ":/images/button-offline.png";
     }
+
+    statusBarLabel->setPixmap(QPixmap(iconFile).scaled(16, 16));
 }
 
 
@@ -530,8 +570,14 @@ void MainWindow::connectToServer(QString jid, QString password,
     this->generalModule->setConnecting();
     this->sessionConnectAction->setDisabled(true);
 
-    this->xmppClient->connectToServer(userJid + "/" + userResource,
-                                      password);
+    QXmppConfiguration clientConfig;
+    clientConfig.setJid(userJid);
+    clientConfig.setResource(userResource);
+    clientConfig.setPassword(password);
+    clientConfig.setKeepAliveTimeout(this->globalObject->getKeepAliveTimeout());
+    clientConfig.setKeepAliveInterval(this->globalObject->getKeepAliveInterval());
+
+    this->xmppClient->connectToServer(clientConfig);
 }
 
 
@@ -561,13 +607,13 @@ void MainWindow::onConnected()
 
     this->globalObject->setConnected(true);
     this->setTitleAndTrayInfo();
-    this->setStatusIconOnline(true);
+    this->setStatusIconOnline(QXmppPresence::Online, true);
 }
 
 
 void MainWindow::onDisconnected()
 {
-    QString message = tr("Disconnected.");
+    const QString message = tr("Disconnected.");
     this->generalModule->setInfoMessage(message);
     this->globalObject->addToLog(message);
 
@@ -576,7 +622,7 @@ void MainWindow::onDisconnected()
 
     this->globalObject->setConnected(false);
     this->setTitleAndTrayInfo();
-    this->setStatusIconOnline(false);
+    this->setStatusIconOnline(QXmppPresence::Online, false);
 
     if (globalObject->getNotifyDisconnection())
     {
@@ -589,19 +635,16 @@ void MainWindow::onDisconnected()
 }
 
 
+void MainWindow::onStatusChanged(QXmppPresence presence)
+{
+    this->setStatusIconOnline(presence.availableStatusType(),
+                              this->globalObject->connectedToServer());
+}
+
+
 void MainWindow::processMessage(QXmppMessage message)
 {
-    if (message.body().startsWith(this->globalObject->getCommandPrefix())
-     && message.type() != QXmppMessage::Error)
-    {
-        this->commandHandler->processCommand(message);
-    }
-    else
-    {
-        this->messageHandler->processMessage(message);
-    }
-
-    // Send private messages to their tabs
+    // Send private messages to their tabs, first (order is important)
     if (message.type() == QXmppMessage::Chat
      || message.type() == QXmppMessage::Normal)
     {
@@ -613,6 +656,18 @@ void MainWindow::processMessage(QXmppMessage message)
         }
     }
 
+
+    // Afterwards, actually process the received message
+    if (message.body().startsWith(this->globalObject->getCommandPrefix())
+     && message.type() != QXmppMessage::Error)
+    {
+        this->commandHandler->processCommand(message);
+    }
+    else
+    {
+        this->messageHandler->processMessage(message);
+    }
+
     //qDebug() << "processMessage() " << message.error().text()
     //             << message.error().code();
 }
@@ -626,10 +681,13 @@ void MainWindow::processPresence(QXmppPresence presence)
 
 void MainWindow::processIq(QXmppIq iq)
 {
-    qDebug() << "IQ received:" << iq.from() << iq.type();
+    qDebug() << QTime::currentTime().toString() << "IQ received:"
+             << iq.from() << iq.to() << iq.type() << iq.id();
 
-    // This causes crashes sometimes
-    //qDebug() << iq.extensions().first().tagName();
+    foreach (QXmppElement iqExt, iq.extensions())
+    {
+        qDebug() << iqExt.tagName();
+    }
 }
 
 
@@ -670,7 +728,12 @@ void MainWindow::setChatsTitle(int count)
     QString title = tr("Chats");
     if (count > 0)
     {
-        title.append(QString("  (%1)").arg(count));
+        // FIXME: this has some issues if the translated title is long
+        title.prepend(QStringLiteral("* "));
+        title.append(QString("\n--  %1  --").arg(count));
+        // TODO: maybe hint with color, like:
+        //// categoriesList->item(2)->setBackgroundColor(Qt::red);
+        //// categoriesList->item(2)->setTextColor(Qt::white);
     }
     this->categoriesList->item(2)->setText(title);
 
@@ -693,6 +756,13 @@ void MainWindow::visitBugTracker()
 }
 
 
+void MainWindow::visitXmppOrg()
+{
+    qDebug() << "Opening XMPP.org in browser";
+    QDesktopServices::openUrl(QUrl("https://xmpp.org/about/technology-overview.html"));
+}
+
+
 /*
  * About... window
  *
@@ -703,20 +773,17 @@ void MainWindow::aboutAkariXB()
                        tr("About AkariXB"),
                        QString("<big><b>AkariXB v%1</b></big>")
                        .arg(qApp->applicationVersion())
-                       + "<br>"
-                         "Copyright 2015-2016  JanKusanagi<br><br>"
+                       + "<br />"
+                         "Copyright 2015-2018  JanKusanagi<br />"
                          "<a href=\"https://jancoding.wordpress.com/akarixb\">"
-                         "https://jancoding.wordpress.com/akarixb</a><br>"
-                         "<br>"
-                         "<br>"
+                         "https://jancoding.wordpress.com/akarixb</a><br />"
+                         "<br />"
                        + tr("AkariXB is a Jabber/XMPP bot.")
-                       + "<br>"
+                       + "<br />"
 
                        + tr("You can talk to it, make it join chatrooms, etc.")
-                       + "<br>"
 
-                         "<hr>" // ---
-                         "<br>"
+                       + "<hr>" // ---
 
                        + tr("English translation by JanKusanagi.",
                             "TRANSLATORS: Change this with your language "
@@ -727,10 +794,8 @@ void MainWindow::aboutAkariXB()
 
                        + tr("Thanks to all the testers, translators and "
                             "packagers, who help make AkariXB better!")
-                       + "<br>"
 
-                         "<hr>" // ---
-                         "<br>"
+                       + "<hr>" // ---
 
                        + tr("AkariXB is Free Software, licensed under the "
                             "GNU GPL license, and uses some Oxygen icons "
@@ -748,14 +813,16 @@ void MainWindow::aboutAkariXB()
                          "<br>"
 
                        + QString("<b>Qt</b> v%1").arg(qVersion())
-                       + "<br>");
+                       + QString(" &mdash; %1").arg(qApp->platformName())
+                       + QString("<br>"
+                                 "<b>QXMPP</b> v%1").arg(QXmppVersion()));
 }
 
 
 void MainWindow::setTitleAndTrayInfo()
 {
-    QString currentTabTitle = "#";
-    QString offlineString = " (" + tr("Offline") + ")";
+    QString currentTabTitle = QStringLiteral("#");
+    const QString offlineString = " (" + tr("Offline") + ")";
 
     if (this->categoriesList->currentRow() != -1)
     {
@@ -765,7 +832,8 @@ void MainWindow::setTitleAndTrayInfo()
     QString title = currentTabTitle;
     if (!this->userJid.isEmpty())
     {
-        title.append(" - " + this->userJid);
+        title.append(QString(" - %1/%2")
+                     .arg(this->userJid, this->userResource));
     }
 
     if (this->globalObject->connectedToServer())
@@ -783,25 +851,23 @@ void MainWindow::setTitleAndTrayInfo()
     this->setWindowTitle(title);
     if (/*trayIconAvailable*/true) // FIXME
     {
-        QString idToShow = this->userJid.isEmpty()
-                           ? tr("Account is not configured")
-                             : userJid + "/" + userResource;
+        const QString idToShow = this->userJid.isEmpty()
+                                 ? tr("Account is not configured")
+                                 : userJid + "/" + userResource;
 #ifdef Q_OS_UNIX
         title = "<b>AkariXB</b>"
                 "<hr>"
                 "<br>"
                 + idToShow
                 + (this->globalObject->connectedToServer() ?
-                   "" : offlineString)
-                + "<br>";
+                   "" : offlineString);
 #else
         // Some OSes don't render HTML in the tray tooltip
         title = "AkariXB: "
                 "\n\n"
                 + idToShow
                 + (this->globalObject->connectedToServer() ?
-                   "" : offlineString)
-                + "\n";
+                   "" : offlineString);
 #endif
 
 
@@ -823,8 +889,15 @@ void MainWindow::showNotification(QString title, QString message)
 {
     if (/*trayIconAvailable*/true) // FIXME
     {
-        this->systrayIcon->showMessage(title, message,
-                                       QSystemTrayIcon::Information, // FIXME, make variable
+        this->systrayIcon->showMessage(title + " - AkariXB",
+                                       message,
+#if QT_VERSION < QT_VERSION_CHECK(5, 9, 0)
+                                       QSystemTrayIcon::Information,
+#else
+                                       // This overload requires 5.9+
+                                       QIcon::fromTheme("akarixb",
+                                                        QIcon::fromTheme("dialog-information")),
+#endif
                                        10000); // 10 secs
     }
 }
@@ -843,9 +916,10 @@ void MainWindow::trayControl(QSystemTrayIcon::ActivationReason reason)
         // Hide or show the main window
         if (this->isMinimized())
         {
-            // hide and show, because raise() wouldn't work
+            // Hide and show, because raise() wouldn't work
             this->hide();
             this->showNormal();
+            this->activateWindow();
             qDebug() << "RAISING from minimized state";
         }
         else
@@ -856,12 +930,20 @@ void MainWindow::trayControl(QSystemTrayIcon::ActivationReason reason)
 }
 
 
-void MainWindow::toggleMainWindow()
+void MainWindow::toggleMainWindow(bool onStartup)
 {
-    if (this->isHidden() /*|| !this->trayIconAvailable*/)
+    bool shouldHide = false;
+    if (onStartup)
+    {
+        shouldHide = this->globalObject->getHideInTray();
+    }
+
+    if (this->isHidden() && !shouldHide
+        /*|| !this->trayIconAvailable*/)
     {
         this->trayShowWindowAction->setText(tr("&Hide Window"));
         this->show();
+        this->activateWindow(); // Try to show it on top of others
         qDebug() << "SHOWING main window";
     }
     else
@@ -881,6 +963,17 @@ void MainWindow::quitProgram()
         this->show();
     }
 
+    // FIXME: make confirmation optional, with option of asking only if via tray
+    int confirmation = QMessageBox::question(this, tr("Quit?") + " - AkariXB",
+                                             tr("Are you sure?"),
+                                             tr("Yes, quit AkariXB"), tr("No"),
+                                             "", 1, 1);
+    if (confirmation == 1)
+    {
+        return;
+    }
+
+
     qApp->setQuitOnLastWindowClosed(true);
 
     std::cout << "\nShutting down AkariXB (" + this->userJid.toStdString()
