@@ -1,6 +1,6 @@
 /*
  *   This file is part of AkariXB
- *   Copyright 2015-2016  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2015-2018  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -47,6 +47,7 @@
 #include <QXmppMessage.h>
 #include <QXmppMucManager.h>
 #include <QXmppVersionManager.h>
+#include <QXmppMessageReceiptManager.h>
 
 #include <iostream>
 
@@ -89,7 +90,8 @@ public:
     void loadSettings();
     void saveSettings();
 
-    void setStatusIconOnline(bool state);
+    void setStatusIconOnline(QXmppPresence::AvailableStatusType statusType,
+                             bool isOnline);
 
 
 public slots:
@@ -98,6 +100,7 @@ public slots:
                          int priority);
     void onConnected();
     void onDisconnected();
+    void onStatusChanged(QXmppPresence presence);
 
     void processMessage(QXmppMessage message);
     void processPresence(QXmppPresence presence);
@@ -109,13 +112,14 @@ public slots:
 
     void visitWebsite();
     void visitBugTracker();
+    void visitXmppOrg();
     void aboutAkariXB();
 
     void setTitleAndTrayInfo();
     void setStatusBarMessage(QString message);
     void showNotification(QString title, QString message);
     void trayControl(QSystemTrayIcon::ActivationReason reason);
-    void toggleMainWindow();
+    void toggleMainWindow(bool onStartup=false);
     void quitProgram();
 
 
@@ -139,6 +143,7 @@ private:
     QMenu *helpMenu;
     QAction *helpWebsiteAction;
     QAction *helpBugTrackerAction;
+    QAction *helpAboutXmppAction;
     QAction *helpAboutAction;
 
 
@@ -178,6 +183,7 @@ private:
     // XMPP
     QXmppClient *xmppClient;
     QXmppMucManager *mucManager;
+    QXmppMessageReceiptManager *receiptManager;
 
 
     QString userJid;
