@@ -1,6 +1,6 @@
 /*
  *   This file is part of AkariXB
- *   Copyright 2015-2016  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2015-2018  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -24,11 +24,11 @@
 MessageHandler::MessageHandler(GlobalObject *globalObject,
                                QObject *parent) : QObject(parent)
 {
-    this->globalObj = globalObject;
-    this->varParser = this->globalObj->getVariableParser();
+    m_globalObject = globalObject;
+    m_variableParser = m_globalObject->getVariableParser();
 
-    this->xmppClient = this->globalObj->getXmppClient();
-    this->mucManager = this->globalObj->getMucManager();
+    m_xmppClient = m_globalObject->getXmppClient();
+    m_mucManager = m_globalObject->getMucManager();
 
 
     qDebug() << "MessageHandler created";
@@ -51,10 +51,10 @@ void MessageHandler::processMessage(QXmppMessage message)
     if (message.type() == QXmppMessage::GroupChat)
     {
         // Find the matching room object
-        QXmppMucRoom *room = this->globalObj->roomFromJid(bareFrom);
+        QXmppMucRoom *room = m_globalObject->roomFromJid(bareFrom);
         if (room)
         {
-            QString fromNick = from.join("/");
+            const QString fromNick = from.join("/");
 
             // tmp greeting thing
             if (message.body().startsWith(room->nickName(), Qt::CaseInsensitive)
@@ -76,18 +76,20 @@ void MessageHandler::processMessage(QXmppMessage message)
     {
         if (!message.body().isEmpty())
         {
-            xmppClient->sendMessage(message.from(),
-                                    this->varParser->getParsed("Hi{!|!!|!!!} %smiley%")); // tmp FIXME
+            m_globalObject->sendPrivateMessage(message.from(),
+                                               m_variableParser
+                                               ->getParsed("Hi{!|!!|!!!} "
+                                                           "%smiley%")); // tmp FIXME
         }
     }
     else
     {
-        QString errorMessage = tr("Error %1 from %2: %3")
-                               .arg(message.error().code())
-                               .arg(message.from())
-                               .arg(message.error().text());
+        const QString errorMessage = tr("Error %1 from %2: %3")
+                                     .arg(message.error().code())
+                                     .arg(message.from())
+                                     .arg(message.error().text());
 
-        this->globalObj->addToLog(errorMessage);
+        m_globalObject->addToLog(errorMessage);
 
         qDebug() << "Message type is Error or Headline:";
         qDebug() << "Subject:" << message.subject();
