@@ -1,6 +1,6 @@
 /*
  *   This file is part of AkariXB
- *   Copyright 2015-2016  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2015-2018  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -305,6 +305,9 @@ QListWidgetItem *RoomModule::listItemFromJid(QString roomJid)
  */
 int RoomModule::stackIndexFromJid(QString roomJid)
 {
+    qDebug() << "RoomModule::stackIndexFromJid()" << roomJid;
+    qDebug() << openedRooms;
+
     int page = 1; // Starts with 1, since 0 is an empty page with no chat
     foreach (ChatWidget *chat, openedRooms)
     {
@@ -382,6 +385,11 @@ void RoomModule::leaveRoom(QString roomJid, QString reason)
                                        QIcon(":/images/button-offline.png")));
         this->showRoomDetails(item);
     }
+    else
+    {
+        qDebug() << "Trying to leave: " << roomJid;
+        qDebug() << "Room NOT FOUND via globalObject!";
+    }
 }
 
 
@@ -546,6 +554,11 @@ void RoomModule::removeRoom()
 
         delete selectedItem;
         this->toggleRoomDetails(false);
+
+        if (roomListWidget->count() == 0)
+        {
+            removeRoomButton->setDisabled(true);
+        }
     }
 }
 
@@ -591,6 +604,11 @@ void RoomModule::changeNick()
 
 void RoomModule::showRoomDetails(QListWidgetItem *item)
 {
+    if (item == 0) // FIXME: needs safer checks
+    {
+        return;
+    }
+
     //qDebug() << "showRoomDetails()" << item->data(Qt::UserRole).toString();
     this->roomJidLineEdit->setText(item->data(Qt::UserRole).toString());
     this->nickLineEdit->setText(item->data(Qt::UserRole + 1).toString());
@@ -606,7 +624,7 @@ void RoomModule::showRoomDetails(QListWidgetItem *item)
     this->toggleJoinLeaveButtons(item);
 
 
-    int stackPos = this->stackIndexFromJid(this->roomJidLineEdit->text());
+    const int stackPos = this->stackIndexFromJid(roomJidLineEdit->text());
     this->chatStackedWidget->setCurrentIndex(stackPos);
 }
 
