@@ -1,6 +1,6 @@
 /*
  *   This file is part of AkariXB
- *   Copyright 2015-2016  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2015-2018  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -60,9 +60,13 @@ StringListWidget::StringListWidget(bool keyValue,
         connect(listWidget, SIGNAL(currentRowChanged(int)),
                 this, SLOT(onRowChanged(int)));
 
-        this->updateButton = new QPushButton("<", this); // FIXME
-        connect(updateButton, SIGNAL(clicked()),
-                this, SLOT(updateItemText()));
+        m_updateButton = new QPushButton(QIcon::fromTheme("dialog-ok-apply",
+                                                          QIcon(":/images/button-apply.png")),
+                                         QString(),
+                                         this);
+        m_updateButton->setDisabled(true);
+        connect(m_updateButton, &QAbstractButton::clicked,
+                this, &StringListWidget::updateItemText);
     }
 
 
@@ -81,7 +85,7 @@ StringListWidget::StringListWidget(bool keyValue,
     if (this->forKeyValue)
     {
         mainLayout->addWidget(itemTextEdit, 3);
-        mainLayout->addWidget(updateButton);
+        mainLayout->addWidget(m_updateButton);
     }
 
     this->setLayout(mainLayout);
@@ -197,6 +201,9 @@ void StringListWidget::addToList()
         int lastRow = listWidget->count() - 1;
         listWidget->setCurrentRow(lastRow);
 
+        this->editButton->setEnabled(true);
+        this->removeButton->setEnabled(true);
+
         if (this->forKeyValue)
         {
             itemTextEdit->setFocus();
@@ -245,10 +252,16 @@ void StringListWidget::removeFromList()
         delete item;
     }
 
-    if (listWidget->count() == 0 // No items left
-     && forKeyValue)
+    if (listWidget->count() == 0) // No items left
     {
-        this->itemTextEdit->setDisabled(true);
+        this->editButton->setDisabled(true);
+        this->removeButton->setDisabled(true);
+
+        if (forKeyValue)
+        {
+            this->itemTextEdit->setDisabled(true);
+            m_updateButton->setDisabled(true);
+        }
     }
 }
 
@@ -264,6 +277,7 @@ void StringListWidget::onRowChanged(int row)
 
     this->itemTextEdit->setText(itemText);
     itemTextEdit->setEnabled(true);
+    m_updateButton->setEnabled(true);
 }
 
 
