@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="ca_ES">
+<TS version="2.1" language="ca_ES">
 <context>
     <name>ActivityHandler</name>
     <message>
@@ -21,7 +21,6 @@
         <translation>
             <numerusform>1 hora</numerusform>
             <numerusform>%Ln hores</numerusform>
-            <numerusform>%Ln hores</numerusform>
         </translation>
     </message>
     <message numerus="yes">
@@ -29,7 +28,6 @@
         <translation>
             <numerusform>1 minut</numerusform>
             <numerusform>%Ln minuts</numerusform>
-            <numerusform>%Ln minuts</numerusform>
         </translation>
     </message>
 </context>
@@ -37,7 +35,7 @@
     <name>ActivityModule</name>
     <message>
         <source>&amp;Add Activity</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Afegir activitat</translation>
     </message>
     <message>
         <source>minutes</source>
@@ -45,23 +43,23 @@
     </message>
     <message>
         <source>Online</source>
-        <translation type="unfinished"></translation>
+        <translation>Connectat</translation>
     </message>
     <message>
         <source>Free for Chat</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Disponible per xerrar</translation>
     </message>
     <message>
         <source>Away</source>
-        <translation type="unfinished">Ausent</translation>
+        <translation>Ausent</translation>
     </message>
     <message>
         <source>Extended Away</source>
-        <translation type="unfinished"></translation>
+        <translation>No disponible</translation>
     </message>
     <message>
         <source>Do not Disturb</source>
-        <translation type="unfinished"></translation>
+        <translation>No molestar</translation>
     </message>
     <message>
         <source>seconds</source>
@@ -73,19 +71,19 @@
     </message>
     <message>
         <source>Several rooms</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Algunes sales</translation>
     </message>
     <message>
         <source>A few rooms</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Unes poques sales</translation>
     </message>
     <message>
         <source>Also to active private chats</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">També a converses privades actives</translation>
     </message>
     <message>
         <source>Sa&amp;ve Activity</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">&amp;Guardar activitat</translation>
     </message>
     <message>
         <source>Name</source>
@@ -101,11 +99,11 @@
     </message>
     <message>
         <source>Time Range</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Rang d&apos;hores</translation>
     </message>
     <message>
         <source>Date Range</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Rang de dates</translation>
     </message>
     <message>
         <source>Duration</source>
@@ -113,7 +111,7 @@
     </message>
     <message>
         <source>Set Status Type</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Establir el tipus d&apos;estat</translation>
     </message>
     <message>
         <source>Availability</source>
@@ -137,11 +135,11 @@
     </message>
     <message>
         <source>&amp;Sync Activities</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">&amp;Sincronitzar activitats</translation>
     </message>
     <message>
         <source>&amp;Remove Activity</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">&amp;Treure activitat</translation>
     </message>
     <message>
         <source>Messages Afterwards</source>
@@ -157,15 +155,11 @@
     </message>
     <message>
         <source>Error: There is already an activity in the list with this name.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Specific JIDs</source>
-        <translation type="unfinished"></translation>
+        <translation>Error: Ja hi ha una activitat a la llista amb aquest nom.</translation>
     </message>
     <message>
         <source>List of room or user addresses, separated by space</source>
-        <translation type="unfinished"></translation>
+        <translation>Llista d&apos;adreces de sales o d&apos;usuaris, separades per espais</translation>
     </message>
     <message>
         <source>Status Messages</source>
@@ -176,7 +170,6 @@
         <translation>
             <numerusform>S&apos;ha guardat 1 activitat.</numerusform>
             <numerusform>S&apos;han guardat %Ln activitats.</numerusform>
-            <numerusform>S&apos;han guardat %Ln activitats.</numerusform>
         </translation>
     </message>
     <message numerus="yes">
@@ -184,9 +177,17 @@
         <translation>
             <numerusform>S&apos;ha carregat 1 activitat.</numerusform>
             <numerusform>S&apos;han carregat %Ln activitats.</numerusform>
-            <numerusform>S&apos;han carregat %Ln activitats.</numerusform>
         </translation>
     </message>
+    <message>
+        <source>None of the rooms</source>
+        <translation>Cap de les sales</translation>
+    </message>
+    <message>
+        <source>Additional specific JIDs:</source>
+        <translatorcomment>FIXME: masculi o femeni? IDentificador vs IDentificació</translatorcomment>
+        <translation type="unfinished">JIDs específics adicionals:</translation>
+    </message>
 </context>
 <context>
     <name>ChatModule</name>
@@ -197,11 +198,11 @@
     </message>
     <message>
         <source>New chat</source>
-        <translation type="unfinished">Nova conversa</translation>
+        <translation>Nova conversa</translation>
     </message>
     <message>
         <source>A new chat was started by %1.</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">%1 ha començat una nova conversa.</translation>
     </message>
 </context>
 <context>
@@ -216,11 +217,11 @@
     </message>
     <message>
         <source>Joined room %1, as %2.</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">S&apos;ha entrat a la sala %1, com %2.</translation>
     </message>
     <message>
         <source>Left room %1.</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">S&apos;ha sortit de la sala %1.</translation>
     </message>
 </context>
 <context>
@@ -247,11 +248,11 @@
     </message>
     <message>
         <source>I don&apos;t have help about: %1</source>
-        <translation type="unfinished"></translation>
+        <translation>No tinc ajuda sobre: %1</translation>
     </message>
     <message>
         <source>Help for %1:</source>
-        <translation type="unfinished">Ajuda de %1:</translation>
+        <translation>Ajuda de %1:</translation>
     </message>
     <message>
         <source>Available commands</source>
@@ -263,7 +264,7 @@
     </message>
     <message>
         <source>I need a parameter for the query.</source>
-        <translation type="unfinished">Necessito un paràmetre per la consulta.</translation>
+        <translation type="vanished">Necessito un paràmetre per la consulta.</translation>
     </message>
     <message>
         <source>I don&apos;t have a match for %1</source>
@@ -273,6 +274,22 @@
         <source>This command is an alias to itself!</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Use %1 to list the available commands.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Use %1 [command] to get help about a specific command.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Started detached program successfully.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>I need a parameter for the query:</source>
+        <translation>Necessito un paràmetre per la consulta:</translation>
+    </message>
 </context>
 <context>
     <name>CommandModule</name>
@@ -327,7 +344,7 @@
     </message>
     <message>
         <source>Run Program</source>
-        <translation type="unfinished">Executar un programa</translation>
+        <translation>Executar un programa</translation>
     </message>
     <message>
         <source>Alias for another command</source>
@@ -335,23 +352,23 @@
     </message>
     <message>
         <source>Select File...</source>
-        <translation type="unfinished"></translation>
+        <translation>Seleccionar arxiu...</translation>
     </message>
     <message>
         <source>Static reply is empty.</source>
-        <translation type="unfinished"></translation>
+        <translation>La resposta estàtica està buida.</translation>
     </message>
     <message>
         <source>There are no sentences in the list.</source>
-        <translation type="unfinished"></translation>
+        <translation>No hi ha frases a la llista.</translation>
     </message>
     <message>
         <source>There is no file selected.</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">No s&apos;ha seleccionat cap arxiu.</translation>
     </message>
     <message>
         <source>There is no program specified.</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">No s&apos;ha especificat cap programa.</translation>
     </message>
     <message>
         <source>You need to enter the command this alias will execute.</source>
@@ -363,7 +380,7 @@
     </message>
     <message>
         <source>Select a text file</source>
-        <translation type="unfinished"></translation>
+        <translation>Selecciona un arxiu de text</translation>
     </message>
     <message>
         <source>Selected file does not exist.</source>
@@ -381,10 +398,6 @@
         <source>Command exists</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Error: There is already a command in the list with this trigger.</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Just enter a single sentence.</source>
         <translation type="unfinished"></translation>
@@ -407,24 +420,10 @@ File encoding should be UTF-8.</source>
         <source>Add keywords to the list, then enter the corresponding definition for each keyword on the other side.</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Enter a command to be run, with any needed parameters.
-The reply will be the console output of the program, unless you specify an output pattern, and don&apos;t include the %output% variable somewhere in it.</source>
-        <comment>Don&apos;t translate %output%!</comment>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Enter the original command that should be run when this alias is used.</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Optional, like: [RESULT] %line% %output%</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Output Pattern</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Private Reply</source>
         <translation type="unfinished">Resposta privada</translation>
@@ -442,7 +441,6 @@ The reply will be the console output of the program, unless you specify an outpu
         <translation>
             <numerusform>S&apos;ha carregat 1 ordre.</numerusform>
             <numerusform>S&apos;han carregat %Ln ordres.</numerusform>
-            <numerusform>S&apos;han carregat %Ln ordres.</numerusform>
         </translation>
     </message>
     <message numerus="yes">
@@ -450,9 +448,42 @@ The reply will be the console output of the program, unless you specify an outpu
         <translation>
             <numerusform>S&apos;ha guardat 1 ordre.</numerusform>
             <numerusform>S&apos;han guardat %Ln ordres.</numerusform>
-            <numerusform>S&apos;han guardat %Ln ordres.</numerusform>
         </translation>
     </message>
+    <message>
+        <source>If the program you launch will take a long time to finish (like a GUI), you need to select the option to launch it independently, but then it will not be possible to use the program output as the reply for the command.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Wait for the program to finish</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Launch the program independently</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Optional, like: [RESULT]</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The name, without the prefix</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Error: There is already a command in the list with this name.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Enter a system command line to be run, with any needed parameters.
+The reply will be the console output of the program, unless you specify a reply pattern, and don&apos;t include the %output% variable somewhere in it.</source>
+        <comment>Don&apos;t translate %output%!</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Reply Pattern</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ConfigDialog</name>
@@ -509,6 +540,10 @@ The reply will be the console output of the program, unless you specify an outpu
         <source>Notify disconnection</source>
         <translation>Notificar desconnexió</translation>
     </message>
+    <message>
+        <source>Connection ping interval</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ConnectionDialog</name>
@@ -580,7 +615,7 @@ The reply will be the console output of the program, unless you specify an outpu
     </message>
     <message>
         <source>Nickname</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Sobrenom</translation>
     </message>
     <message>
         <source>Loaded identity data for %1.</source>
@@ -641,7 +676,7 @@ The reply will be the console output of the program, unless you specify an outpu
     </message>
     <message>
         <source>Thanks to all the testers, translators and packagers, who help make AkariXB better!</source>
-        <translation type="unfinished"></translation>
+        <translation>Gràcies a tots els &apos;testers&apos;, traductors i empaquetadors, que ajuden a fer AkariXB millor!</translation>
     </message>
     <message>
         <source>&amp;Hide Window</source>
@@ -669,7 +704,7 @@ The reply will be the console output of the program, unless you specify an outpu
     </message>
     <message>
         <source>Visit Website</source>
-        <translation type="unfinished"></translation>
+        <translation>Visitar lloc web</translation>
     </message>
     <message>
         <source>Report a Bug</source>
@@ -685,7 +720,7 @@ The reply will be the console output of the program, unless you specify an outpu
     </message>
     <message>
         <source>Network error: %1</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Error de xarxa: %1</translation>
     </message>
     <message>
         <source>Chats</source>
@@ -693,7 +728,7 @@ The reply will be the console output of the program, unless you specify an outpu
     </message>
     <message>
         <source>Commands</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Ordres</translation>
     </message>
     <message>
         <source>Conversation</source>
@@ -705,7 +740,7 @@ The reply will be the console output of the program, unless you specify an outpu
     </message>
     <message>
         <source>AkariXB is Free Software, licensed under the GNU GPL license, and uses some Oxygen icons under LGPL license.</source>
-        <translation type="unfinished"></translation>
+        <translation>AkariXB es software lliure, llicenciat sota la llicència GNU GPL, i utilitza algunes icones Oxygen amb llicència LGPL.</translation>
     </message>
     <message>
         <source>Account is not configured</source>
@@ -725,23 +760,23 @@ The reply will be the console output of the program, unless you specify an outpu
     </message>
     <message>
         <source>Identity</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Identitat</translation>
     </message>
     <message>
         <source>Ready.</source>
-        <translation type="unfinished"></translation>
+        <translation>Preparat.</translation>
     </message>
     <message>
         <source>&amp;Session</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Sessió</translation>
     </message>
     <message>
         <source>S&amp;ettings</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">&amp;Configuració</translation>
     </message>
     <message>
         <source>&amp;Help</source>
-        <translation type="unfinished"></translation>
+        <translation>Aj&amp;uda</translation>
     </message>
     <message>
         <source>Disconnected</source>
@@ -749,7 +784,7 @@ The reply will be the console output of the program, unless you specify an outpu
     </message>
     <message>
         <source>Connection to the server was lost.</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">S&apos;ha perdut la connexió amb el servidor.</translation>
     </message>
     <message>
         <source>Socket Error</source>
@@ -763,6 +798,26 @@ The reply will be the console output of the program, unless you specify an outpu
         <source>XMPP Stream Error</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>About XMPP</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Quit?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Are you sure?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Yes, quit AkariXB</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>No</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MessageHandler</name>
@@ -783,15 +838,16 @@ The reply will be the console output of the program, unless you specify an outpu
     </message>
     <message>
         <source>Room address</source>
-        <translation type="unfinished">Adreça de la sala</translation>
+        <translation>Adreça de la sala</translation>
     </message>
     <message>
         <source>Nickname</source>
-        <translation type="unfinished"></translation>
+        <translatorcomment>meh...</translatorcomment>
+        <translation type="unfinished">Sobrenom</translation>
     </message>
     <message>
         <source>Autojoin</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Auto-entrar</translation>
     </message>
     <message>
         <source>Join</source>
@@ -843,22 +899,21 @@ The reply will be the console output of the program, unless you specify an outpu
     </message>
     <message>
         <source>Joining room %1...</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Entrant a al sala %1...</translation>
     </message>
     <message>
         <source>Password, if needed</source>
-        <translation type="unfinished">Contrasenya, si cal</translation>
+        <translation>Contrasenya, si cal</translation>
     </message>
     <message>
         <source>Password</source>
-        <translation type="unfinished">Contrasenya</translation>
+        <translation>Contrasenya</translation>
     </message>
     <message numerus="yes">
         <source>Loaded %Ln room(s).</source>
         <translation>
             <numerusform>S&apos;ha carregat 1 sala.</numerusform>
             <numerusform>S&apos;han carregat %Ln sales.</numerusform>
-            <numerusform>S&apos;han carregat %Ln sales.</numerusform>
         </translation>
     </message>
 </context>
