@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="es_ES">
+<TS version="2.1" language="es_ES">
 <context>
     <name>ActivityHandler</name>
     <message>
@@ -35,7 +35,7 @@
     <name>ActivityModule</name>
     <message>
         <source>&amp;Add Activity</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Añadir actividad</translation>
     </message>
     <message>
         <source>minutes</source>
@@ -43,23 +43,24 @@
     </message>
     <message>
         <source>Online</source>
-        <translation type="unfinished"></translation>
+        <translation>Conectado</translation>
     </message>
     <message>
         <source>Free for Chat</source>
-        <translation type="unfinished"></translation>
+        <translatorcomment>&quot;charlar&quot;, como lo traducen en Psi</translatorcomment>
+        <translation>Disponible para charlar</translation>
     </message>
     <message>
         <source>Away</source>
-        <translation type="unfinished">Ausente</translation>
+        <translation>Ausente</translation>
     </message>
     <message>
         <source>Extended Away</source>
-        <translation type="unfinished"></translation>
+        <translation>No disponible</translation>
     </message>
     <message>
         <source>Do not Disturb</source>
-        <translation type="unfinished"></translation>
+        <translation>No molestar</translation>
     </message>
     <message>
         <source>seconds</source>
@@ -71,19 +72,19 @@
     </message>
     <message>
         <source>Several rooms</source>
-        <translation type="unfinished"></translation>
+        <translation>Varias salas</translation>
     </message>
     <message>
         <source>A few rooms</source>
-        <translation type="unfinished"></translation>
+        <translation>Unas pocas salas</translation>
     </message>
     <message>
         <source>Also to active private chats</source>
-        <translation type="unfinished"></translation>
+        <translation>También a conversaciones privadas activas</translation>
     </message>
     <message>
         <source>Sa&amp;ve Activity</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Guardar actividad</translation>
     </message>
     <message>
         <source>Name</source>
@@ -91,7 +92,7 @@
     </message>
     <message>
         <source>Maximum Times Per Day</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Máximo de veces por día</translation>
     </message>
     <message>
         <source>Probability</source>
@@ -99,11 +100,11 @@
     </message>
     <message>
         <source>Time Range</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Rango de horas</translation>
     </message>
     <message>
         <source>Date Range</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Rango de fechas</translation>
     </message>
     <message>
         <source>Duration</source>
@@ -111,7 +112,7 @@
     </message>
     <message>
         <source>Set Status Type</source>
-        <translation type="unfinished"></translation>
+        <translation>Establecer tipo de estado</translation>
     </message>
     <message>
         <source>Availability</source>
@@ -135,11 +136,11 @@
     </message>
     <message>
         <source>&amp;Sync Activities</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">&amp;Sincronizar actividades</translation>
     </message>
     <message>
         <source>&amp;Remove Activity</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Quitar actividad</translation>
     </message>
     <message>
         <source>Messages Afterwards</source>
@@ -155,15 +156,16 @@
     </message>
     <message>
         <source>Error: There is already an activity in the list with this name.</source>
-        <translation type="unfinished"></translation>
+        <translation>Error: Ya hay una actividad en la lista con este nombre.</translation>
     </message>
     <message>
         <source>Specific JIDs</source>
-        <translation type="unfinished"></translation>
+        <translatorcomment>FIXME: Habría que investigar si JID es masculino (IDentificador Jabber) o femenino (IDentificación Jabber)</translatorcomment>
+        <translation type="obsolete">JIDs específicos</translation>
     </message>
     <message>
         <source>List of room or user addresses, separated by space</source>
-        <translation type="unfinished"></translation>
+        <translation>Lista de direcciones de salas o de usuarios, separadas por espacios</translation>
     </message>
     <message>
         <source>Status Messages</source>
@@ -183,6 +185,15 @@
             <numerusform>Se han cargado %Ln actividades.</numerusform>
         </translation>
     </message>
+    <message>
+        <source>None of the rooms</source>
+        <translation>Ninguna de las salas</translation>
+    </message>
+    <message>
+        <source>Additional specific JIDs:</source>
+        <translatorcomment>FIXME: Habría que decidir si JID es masculino (IDentificador Jabber) o femenino (IDentificación Jabber)</translatorcomment>
+        <translation type="unfinished">JIDs específicos adicionales:</translation>
+    </message>
 </context>
 <context>
     <name>ChatModule</name>
@@ -193,11 +204,11 @@
     </message>
     <message>
         <source>New chat</source>
-        <translation type="unfinished">Nueva conversación</translation>
+        <translation>Nueva conversación</translation>
     </message>
     <message>
         <source>A new chat was started by %1.</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">%1 ha iniciado una nueva conversación.</translation>
     </message>
 </context>
 <context>
@@ -208,73 +219,89 @@
     </message>
     <message>
         <source>Kicked from the room!</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">¡Expulsado de la sala!</translation>
     </message>
     <message>
         <source>Joined room %1, as %2.</source>
-        <translation type="unfinished"></translation>
+        <translation>Se ha entrado a la sala %1, como %2.</translation>
     </message>
     <message>
         <source>Left room %1.</source>
-        <translation type="unfinished"></translation>
+        <translation>Se ha salido de la sala %1.</translation>
     </message>
 </context>
 <context>
     <name>CommandHandler</name>
     <message>
         <source>Command from %1 in room %2: %3</source>
-        <translation type="unfinished"></translation>
+        <translation>Comando de %1 en la sala %2: %3</translation>
     </message>
     <message>
         <source>Command from %1: %2</source>
-        <translation type="unfinished"></translation>
+        <translation>Comando de %1: %2</translation>
     </message>
     <message>
         <source>The command failed.</source>
-        <translation type="unfinished"></translation>
+        <translation>Ha fallado el comando.</translation>
     </message>
     <message>
         <source>Error loading file %1 for command: %2</source>
-        <translation type="unfinished"></translation>
+        <translation>Error al cargar el archivo %1 para el comando: %2</translation>
     </message>
     <message>
         <source>Command gave no output text.</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">El comando no ha dado ningún texto de salida.</translation>
     </message>
     <message>
         <source>I don&apos;t have help about: %1</source>
-        <translation type="unfinished"></translation>
+        <translation>No tengo ayuda sobre: %1</translation>
     </message>
     <message>
         <source>Help for %1:</source>
-        <translation type="unfinished">Ayuda de %1:</translation>
+        <translation>Ayuda de %1:</translation>
     </message>
     <message>
         <source>Available commands</source>
-        <translation type="unfinished"></translation>
+        <translation>Comandos disponibles</translation>
     </message>
     <message>
         <source>Command %1 requested without the right access level.</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Se ha solicitado el comando %1 sin el nivel de acceso adecuado.</translation>
     </message>
     <message>
         <source>I need a parameter for the query.</source>
-        <translation type="unfinished">Necesito un parámetro para la consulta.</translation>
+        <translation type="vanished">Necesito un parámetro para la consulta.</translation>
     </message>
     <message>
         <source>I don&apos;t have a match for %1</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">No tengo ninguna coincidencia para %1</translation>
     </message>
     <message>
         <source>This command is an alias to itself!</source>
-        <translation type="unfinished"></translation>
+        <translation>¡Este comando es un alias para sí mismo!</translation>
+    </message>
+    <message>
+        <source>Use %1 to list the available commands.</source>
+        <translation>Usa %1 para listar los comandos disponibles.</translation>
+    </message>
+    <message>
+        <source>Use %1 [command] to get help about a specific command.</source>
+        <translation>Usa %1 [comando] para recibir ayuda sobre un comando específico.</translation>
+    </message>
+    <message>
+        <source>Started detached program successfully.</source>
+        <translation type="unfinished">Se ha iniciado el programa independiente correctamente.</translation>
+    </message>
+    <message>
+        <source>I need a parameter for the query:</source>
+        <translation>Necesito un parámetro para la consulta:</translation>
     </message>
 </context>
 <context>
     <name>CommandModule</name>
     <message>
         <source>&amp;Add Command</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Añadir comando</translation>
     </message>
     <message>
         <source>Static Message</source>
@@ -282,15 +309,15 @@
     </message>
     <message>
         <source>Random Sentence</source>
-        <translation type="unfinished">Frase aleatoria</translation>
+        <translation>Frase aleatoria</translation>
     </message>
     <message>
         <source>Save &amp;Command</source>
-        <translation type="unfinished"></translation>
+        <translation>Guardar &amp;comando</translation>
     </message>
     <message>
         <source>Command</source>
-        <translation type="unfinished"></translation>
+        <translation>Comando</translation>
     </message>
     <message>
         <source>Help Text</source>
@@ -306,11 +333,11 @@
     </message>
     <message>
         <source>&amp;Sync Commands</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">&amp;Sincronizar comandos</translation>
     </message>
     <message>
         <source>&amp;Remove Command</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Quitar comando</translation>
     </message>
     <message>
         <source>Anyone can use it</source>
@@ -319,119 +346,119 @@
     </message>
     <message>
         <source>Random Line from Text File</source>
-        <translation type="unfinished"></translation>
+        <translation>Línea aleatoria de archivo de texto</translation>
     </message>
     <message>
         <source>Run Program</source>
-        <translation type="unfinished">Ejecutar un programa</translation>
+        <translation>Ejecutar un programa</translation>
     </message>
     <message>
         <source>Alias for another command</source>
-        <translation type="unfinished"></translation>
+        <translation>Alias para otro comando</translation>
     </message>
     <message>
         <source>Select File...</source>
-        <translation type="unfinished"></translation>
+        <translation>Selecciona archivo...</translation>
     </message>
     <message>
         <source>Static reply is empty.</source>
-        <translation type="unfinished"></translation>
+        <translation>La respuesta estática está vacía.</translation>
     </message>
     <message>
         <source>There are no sentences in the list.</source>
-        <translation type="unfinished"></translation>
+        <translation>No hay frases en la lista.</translation>
     </message>
     <message>
         <source>There is no file selected.</source>
-        <translation type="unfinished"></translation>
+        <translation>No hay ningún archivo seleccionado.</translation>
     </message>
     <message>
         <source>There is no program specified.</source>
-        <translation type="unfinished"></translation>
+        <translation>No se ha especificado ningún programa.</translation>
     </message>
     <message>
         <source>You need to enter the command this alias will execute.</source>
-        <translation type="unfinished"></translation>
+        <translation>Debes introducir el comando que este alias ejecutará.</translation>
     </message>
     <message>
         <source>Error validating fields</source>
-        <translation type="unfinished"></translation>
+        <translation>Error validando los campos</translation>
     </message>
     <message>
         <source>Select a text file</source>
-        <translation type="unfinished"></translation>
+        <translation>Selecciona un archivo de texto</translation>
     </message>
     <message>
         <source>Selected file does not exist.</source>
-        <translation type="unfinished"></translation>
+        <translation>El archivo selecionado no existe.</translation>
     </message>
     <message>
         <source>New Command</source>
-        <translation type="unfinished"></translation>
+        <translation>Nuevo comando</translation>
     </message>
     <message>
         <source>No file selected</source>
-        <translation type="unfinished"></translation>
+        <translation>Ningún archivo seleccionado</translation>
     </message>
     <message>
         <source>Command exists</source>
-        <translation type="unfinished"></translation>
+        <translation>El comando ya existe</translation>
     </message>
     <message>
         <source>Error: There is already a command in the list with this trigger.</source>
-        <translation type="unfinished"></translation>
+        <translatorcomment>FIXME</translatorcomment>
+        <translation type="obsolete">Error: Ya hay un comando en la lista con este &apos;trigger&apos;.</translation>
     </message>
     <message>
         <source>Just enter a single sentence.</source>
-        <translation type="unfinished"></translation>
+        <translation>Introduce una única frase.</translation>
     </message>
     <message>
         <source>Add as many sentences as you want.
 One of them will be selected at random as a reply.</source>
-        <translation type="unfinished"></translation>
+        <translation>Añade tantas frases como quieras.
+Una de ellas será seleccionada al azar como respuesta.</translation>
     </message>
     <message>
         <source>A random line from the chosen file will be used as a reply.
 File encoding should be UTF-8.</source>
-        <translation type="unfinished"></translation>
+        <translation>Se utilizará una línea aleatoria del archivo elegido como respuesta.
+La codificación del archivo debe ser UTF-8.</translation>
     </message>
     <message>
         <source>Keyword-based Message</source>
-        <translation type="unfinished"></translation>
+        <translation>Mensaje basado en palabras clave</translation>
     </message>
     <message>
         <source>Add keywords to the list, then enter the corresponding definition for each keyword on the other side.</source>
-        <translation type="unfinished"></translation>
+        <translation>Añade palabras clave a la lista, luego introduce la definición correspondiente para cada palabra clave en el otro lado.</translation>
     </message>
     <message>
         <source>Enter a command to be run, with any needed parameters.
 The reply will be the console output of the program, unless you specify an output pattern, and don&apos;t include the %output% variable somewhere in it.</source>
         <comment>Don&apos;t translate %output%!</comment>
-        <translation type="unfinished"></translation>
+        <translation type="vanished">Introduce un comando para ejecutar, con los parámetros que pueda necesitar.
+La respuesta será la salida en consola del programa, a menos que especifiques un patrón de salida, y no incluyas la variable %output% en algún lugar del mismo.</translation>
     </message>
     <message>
         <source>Enter the original command that should be run when this alias is used.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Optional, like: [RESULT] %line% %output%</source>
-        <translation type="unfinished"></translation>
+        <translation>Introduce el comando original que se debe ejecutar cuando se use este alias.</translation>
     </message>
     <message>
         <source>Output Pattern</source>
-        <translation type="unfinished"></translation>
+        <translation type="obsolete">Patrón de salida</translation>
     </message>
     <message>
         <source>Private Reply</source>
-        <translation type="unfinished">Respuesta privada</translation>
+        <translation>Respuesta en privado</translation>
     </message>
     <message>
         <source>There are no keywords in the list.</source>
-        <translation type="unfinished"></translation>
+        <translation>No hay palabras clave en la lista.</translation>
     </message>
     <message>
         <source>A command can&apos;t be an alias of itself.</source>
-        <translation type="unfinished"></translation>
+        <translation>Un comando no puede ser un alias de sí mismo.</translation>
     </message>
     <message numerus="yes">
         <source>Loaded %Ln command(s).</source>
@@ -447,6 +474,53 @@ The reply will be the console output of the program, unless you specify an outpu
             <numerusform>Se han guardado %Ln comandos.</numerusform>
         </translation>
     </message>
+    <message>
+        <source>The trigger word, without the prefix</source>
+        <translatorcomment>FIXME</translatorcomment>
+        <translation type="obsolete">La palabra &apos;trigger&apos;, sin el prefijo</translation>
+    </message>
+    <message>
+        <source>Enter a system command line to be run, with any needed parameters.
+The reply will be the console output of the program, unless you specify an output pattern, and don&apos;t include the %output% variable somewhere in it.</source>
+        <comment>Don&apos;t translate %output%!</comment>
+        <translation type="obsolete">Introduce una línea de comando del sistema para ejecutar, con los parámetros que pueda necesitar.
+La respuesta será la salida en consola del programa, a menos que especifiques un patrón de salida, y no incluyas la variable %output% en algún lugar del mismo.</translation>
+    </message>
+    <message>
+        <source>If the program you launch will take a long time to finish (like a GUI), you need to select the option to launch it independently, but then it will not be possible to use the program output as the reply for the command.</source>
+        <translation type="unfinished">Si el programa que lanzas va a tardar mucho tiempo en terminar (como un GUI), debes seleccionar la opción de lanzarlo independientemente, pero entonces no será posible usar la salida del programa como respuesta para el comando.</translation>
+    </message>
+    <message>
+        <source>Wait for the program to finish</source>
+        <translation>Esperar a que termine el programa</translation>
+    </message>
+    <message>
+        <source>Launch the program independently</source>
+        <translation type="unfinished">Lanzar el programa independientemente</translation>
+    </message>
+    <message>
+        <source>Optional, like: [RESULT]</source>
+        <translation>Opcional, como: [RESULTADO]</translation>
+    </message>
+    <message>
+        <source>The name, without the prefix</source>
+        <translation type="unfinished">El nombre, sin el prefijo</translation>
+    </message>
+    <message>
+        <source>Error: There is already a command in the list with this name.</source>
+        <translation type="unfinished">Error: Ya hay un comando en la lista con este nombre.</translation>
+    </message>
+    <message>
+        <source>Enter a system command line to be run, with any needed parameters.
+The reply will be the console output of the program, unless you specify a reply pattern, and don&apos;t include the %output% variable somewhere in it.</source>
+        <comment>Don&apos;t translate %output%!</comment>
+        <translation type="unfinished">Introduce una línea de comando del sistema para ejecutar, con los parámetros que pueda necesitar.
+La respuesta será la salida en consola del programa, a menos que especifiques un patrón de respuesta, y no incluyas la variable %output% en algún lugar del mismo.</translation>
+    </message>
+    <message>
+        <source>Reply Pattern</source>
+        <translation>Patrón de respuesta</translation>
+    </message>
 </context>
 <context>
     <name>ConfigDialog</name>
@@ -468,15 +542,15 @@ The reply will be the console output of the program, unless you specify an outpu
     </message>
     <message>
         <source>Command prefix</source>
-        <translation type="unfinished">Prefijo de órdenes</translation>
+        <translation>Prefijo de comandos</translation>
     </message>
     <message>
         <source>Notify new chats</source>
-        <translation type="unfinished">Notificar nuevas conversaciones</translation>
+        <translation>Notificar nuevas conversaciones</translation>
     </message>
     <message>
         <source>Hide window on startup</source>
-        <translation type="unfinished"></translation>
+        <translation>Ocultar ventana al iniciar</translation>
     </message>
     <message>
         <source>Notifications</source>
@@ -484,7 +558,7 @@ The reply will be the console output of the program, unless you specify an outpu
     </message>
     <message>
         <source>System Tray</source>
-        <translation type="unfinished"></translation>
+        <translation>Bandeja del sistema</translation>
     </message>
     <message>
         <source>Cancel</source>
@@ -497,18 +571,22 @@ The reply will be the console output of the program, unless you specify an outpu
     </message>
     <message>
         <source>Connection timeout</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Tiempo máximo de espera de la conexión</translation>
     </message>
     <message>
         <source>Notify disconnection</source>
         <translation>Notificar desconexión</translation>
     </message>
+    <message>
+        <source>Connection ping interval</source>
+        <translation type="unfinished">Intervalo de ping de la conexión</translation>
+    </message>
 </context>
 <context>
     <name>ConnectionDialog</name>
     <message>
         <source>Connection Settings</source>
-        <translation type="unfinished"></translation>
+        <translation>Configuración de la conexión</translation>
     </message>
     <message>
         <source>Cancel</source>
@@ -536,7 +614,7 @@ The reply will be the console output of the program, unless you specify an outpu
     </message>
     <message>
         <source>Like user@server</source>
-        <translation type="unfinished"></translation>
+        <translation>Como usuario@servidor</translation>
     </message>
     <message>
         <source>&amp;Connect</source>
@@ -547,7 +625,7 @@ The reply will be the console output of the program, unless you specify an outpu
     <name>GeneralModule</name>
     <message>
         <source>Offline</source>
-        <translation type="unfinished">No conectado</translation>
+        <translation>Desconectado</translation>
     </message>
     <message>
         <source>Connect</source>
@@ -574,17 +652,17 @@ The reply will be the console output of the program, unless you specify an outpu
     </message>
     <message>
         <source>Nickname</source>
-        <translation type="unfinished"></translation>
+        <translation>Apodo</translation>
     </message>
     <message>
         <source>Loaded identity data for %1.</source>
         <comment>%1 is a nickname</comment>
-        <translation type="unfinished"></translation>
+        <translation>Datos de identidad cargados para %1.</translation>
     </message>
     <message>
         <source>Saved identity data for %1.</source>
         <comment>%1 is a nickname</comment>
-        <translation type="unfinished"></translation>
+        <translation>Datos de identidad guardados para %1.</translation>
     </message>
 </context>
 <context>
@@ -622,20 +700,20 @@ The reply will be the console output of the program, unless you specify an outpu
     </message>
     <message>
         <source>AkariXB is a Jabber/XMPP bot.</source>
-        <translation type="unfinished">AkariXB es un bot para Jabber/XMPP.</translation>
+        <translation>AkariXB es un bot para Jabber/XMPP.</translation>
     </message>
     <message>
         <source>You can talk to it, make it join chatrooms, etc.</source>
-        <translation type="unfinished"></translation>
+        <translation>Puedes hablarle, hacer que entre en salas de charla, etc.</translation>
     </message>
     <message>
         <source>English translation by JanKusanagi.</source>
         <comment>TRANSLATORS: Change this with your language and name. If there was another translator before you, add your name after theirs ;)</comment>
-        <translation>Traducción al castellano por JanKusanagi.</translation>
+        <translation>Traducción al castellano por JanKusanagi y Kheiron.</translation>
     </message>
     <message>
         <source>Thanks to all the testers, translators and packagers, who help make AkariXB better!</source>
-        <translation type="unfinished"></translation>
+        <translation>¡Gracias a todos los &apos;testers&apos;, traductores y empaquetadores, que ayudan a hacer AkariXB mejor!</translation>
     </message>
     <message>
         <source>&amp;Hide Window</source>
@@ -647,7 +725,7 @@ The reply will be the console output of the program, unless you specify an outpu
     </message>
     <message>
         <source>Offline</source>
-        <translation type="unfinished">No conectado</translation>
+        <translation>No conectado</translation>
     </message>
     <message>
         <source>Disconnect</source>
@@ -663,15 +741,15 @@ The reply will be the console output of the program, unless you specify an outpu
     </message>
     <message>
         <source>Visit Website</source>
-        <translation type="unfinished"></translation>
+        <translation>Visitar sitio web</translation>
     </message>
     <message>
         <source>Report a Bug</source>
-        <translation type="unfinished"></translation>
+        <translation>Informar de un error</translation>
     </message>
     <message>
         <source>%1 connected.</source>
-        <translation type="unfinished">%1 conectado.</translation>
+        <translation>%1 conectado.</translation>
     </message>
     <message>
         <source>Disconnected.</source>
@@ -679,31 +757,32 @@ The reply will be the console output of the program, unless you specify an outpu
     </message>
     <message>
         <source>Network error: %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Error de red: %1</translation>
     </message>
     <message>
         <source>Chats</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Conversaciones</translation>
     </message>
     <message>
         <source>Commands</source>
-        <translation type="unfinished"></translation>
+        <translation>Comandos</translation>
     </message>
     <message>
         <source>Conversation</source>
+        <translatorcomment>FIXME</translatorcomment>
         <translation type="unfinished">Conversación</translation>
     </message>
     <message>
         <source>Activities</source>
-        <translation type="unfinished">Actividades</translation>
+        <translation>Actividades</translation>
     </message>
     <message>
         <source>AkariXB is Free Software, licensed under the GNU GPL license, and uses some Oxygen icons under LGPL license.</source>
-        <translation type="unfinished"></translation>
+        <translation>AkariXB es software libre, licenciado bajo GNU GPL, y utiliza algunos iconos Oxygen con licencia LGPL.</translation>
     </message>
     <message>
         <source>Account is not configured</source>
-        <translation>La cuenta no está configurada.</translation>
+        <translation>La cuenta no está configurada</translation>
     </message>
     <message>
         <source>Data directory created: %1</source>
@@ -711,7 +790,7 @@ The reply will be the console output of the program, unless you specify an outpu
     </message>
     <message>
         <source>Error creating data directory: %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Error al crear el directorio de datos: %1</translation>
     </message>
     <message>
         <source>Data directory in use: %1</source>
@@ -719,43 +798,63 @@ The reply will be the console output of the program, unless you specify an outpu
     </message>
     <message>
         <source>Identity</source>
-        <translation type="unfinished"></translation>
+        <translation>Identidad</translation>
     </message>
     <message>
         <source>Ready.</source>
-        <translation type="unfinished"></translation>
+        <translation>Preparado.</translation>
     </message>
     <message>
         <source>&amp;Session</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Sesión</translation>
     </message>
     <message>
         <source>S&amp;ettings</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Configuración</translation>
     </message>
     <message>
         <source>&amp;Help</source>
-        <translation type="unfinished"></translation>
+        <translation>Ay&amp;uda</translation>
     </message>
     <message>
         <source>Disconnected</source>
-        <translation type="unfinished"></translation>
+        <translation>Desconectado</translation>
     </message>
     <message>
         <source>Connection to the server was lost.</source>
-        <translation type="unfinished"></translation>
+        <translation>Se ha perdido la conexión con el servidor.</translation>
     </message>
     <message>
         <source>Socket Error</source>
-        <translation type="unfinished"></translation>
+        <translation>Error de socket</translation>
     </message>
     <message>
         <source>KeepAlive Error</source>
-        <translation type="unfinished"></translation>
+        <translation>Error de KeepAlive</translation>
     </message>
     <message>
         <source>XMPP Stream Error</source>
-        <translation type="unfinished"></translation>
+        <translation>Error de flujo XMPP</translation>
+    </message>
+    <message>
+        <source>About XMPP</source>
+        <translation>Acerca de XMPP</translation>
+    </message>
+    <message>
+        <source>Quit?</source>
+        <translation>¿Salir?</translation>
+    </message>
+    <message>
+        <source>Are you sure?</source>
+        <translation type="unfinished">¿Seguro?</translation>
+    </message>
+    <message>
+        <source>Yes, quit AkariXB</source>
+        <translation>Sí, salir de AkariXB</translation>
+    </message>
+    <message>
+        <source>No</source>
+        <translation>No</translation>
     </message>
 </context>
 <context>
@@ -769,23 +868,23 @@ The reply will be the console output of the program, unless you specify an outpu
     <name>RoomModule</name>
     <message>
         <source>Add &amp;New Room</source>
-        <translation type="unfinished"></translation>
+        <translation>Añadir &amp;nueva sala</translation>
     </message>
     <message>
         <source>&amp;Remove Room</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Quitar sala</translation>
     </message>
     <message>
         <source>Room address</source>
-        <translation type="unfinished">Dirección de la sala</translation>
+        <translation>Dirección de la sala</translation>
     </message>
     <message>
         <source>Nickname</source>
-        <translation type="unfinished"></translation>
+        <translation>Apodo</translation>
     </message>
     <message>
         <source>Autojoin</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Auto-entrar</translation>
     </message>
     <message>
         <source>Join</source>
@@ -797,7 +896,7 @@ The reply will be the console output of the program, unless you specify an outpu
     </message>
     <message>
         <source>Select a room from the list above</source>
-        <translation type="unfinished"></translation>
+        <translation>Selecciona una sala de la lista de arriba</translation>
     </message>
     <message>
         <source>Room Details</source>
@@ -813,19 +912,19 @@ The reply will be the console output of the program, unless you specify an outpu
     </message>
     <message>
         <source>Room address is not valid.</source>
-        <translation type="unfinished"></translation>
+        <translation>La dirección de la sala no es válida.</translation>
     </message>
     <message>
         <source>Nickname is not valid.</source>
-        <translation type="unfinished"></translation>
+        <translation>El apodo no es válido.</translation>
     </message>
     <message>
         <source>New Room</source>
-        <translation type="unfinished">Sala nueva</translation>
+        <translation>Sala nueva</translation>
     </message>
     <message>
         <source>Leaving room %1...</source>
-        <translation type="unfinished"></translation>
+        <translation>Saliendo de la sala %1...</translation>
     </message>
     <message>
         <source>&amp;Edit</source>
@@ -837,15 +936,15 @@ The reply will be the console output of the program, unless you specify an outpu
     </message>
     <message>
         <source>Joining room %1...</source>
-        <translation type="unfinished"></translation>
+        <translation>Entrando a la sala %1...</translation>
     </message>
     <message>
         <source>Password, if needed</source>
-        <translation type="unfinished">Contraseña, si se necesita</translation>
+        <translation>Contraseña, si se necesita</translation>
     </message>
     <message>
         <source>Password</source>
-        <translation type="unfinished">Contraseña</translation>
+        <translation>Contraseña</translation>
     </message>
     <message numerus="yes">
         <source>Loaded %Ln room(s).</source>
